import React, {
  useEffect,
  useMemo
} from "react";
import { TextInput } from "react-native";
const StringInput = React.forwardRef(
  function StringInput2({
    "data-type": dataType,
    onChange,
    onBlur,
    onFocus,
    value,
    maxLength,
    multiline,
    rows,
    disabled,
    ...props
  }, ref) {
    const [currentValue, setValue] = React.useState(value);
    const keyboardType = useMemo(() => {
      switch (dataType) {
        case "afm":
          return "number-pad";
        case "phone_number":
          return "phone-pad";
        case "mobile_phone":
          return "phone-pad";
        case "postal_code":
          return "number-pad";
        case "int":
          return "numeric";
        case "email":
          return "email-address";
        default:
          return "default";
      }
    }, [dataType]);
    useEffect(() => {
      if (currentValue !== value) {
        handleChange();
      }
    }, [currentValue]);
    useEffect(() => {
      if (currentValue !== value) {
        setValue(value);
      }
    }, [value]);
    const handleChange = () => {
      if (onChange) {
        const syntheticEvent = {
          target: {
            value: currentValue
          }
        };
        onChange(syntheticEvent);
      }
    };
    const handleBlur = () => {
      if (onBlur) {
        const syntheticEvent = {
          target: {
            value: currentValue
          }
        };
        onBlur(syntheticEvent);
      }
    };
    const handleFocus = () => {
      if (onFocus) {
        const syntheticEvent = {
          target: {
            value: currentValue
          }
        };
        onFocus(syntheticEvent);
      }
    };
    return /* @__PURE__ */ React.createElement(
      TextInput,
      {
        ref,
        onChangeText: setValue,
        onBlur: handleBlur,
        onFocus: handleFocus,
        value: currentValue,
        multiline,
        rows,
        editable: !disabled,
        maxLength: Number(maxLength) || void 0,
        keyboardType,
        ...props
      }
    );
  }
);
export {
  StringInput
};
//# sourceMappingURL=StringInput.native.js.map
