import React, { useMemo } from "react";
import { Text, View } from "react-native";
import { mapping } from "@digigov/react-core/Base/mapping.native";
import { basePropGenerator } from "@digigov/react-core/Base/utils";
import { wrap } from "@digigov/react-core/Base/wrap.native";
const BooleanMapper = {
  true: true,
  false: false,
  undefined: false,
  null: false,
  "": false
};
const textHtmlTags = ["h1", "h2", "h3", "h4", "h5", "p", "span"];
const Base = React.forwardRef(function Base2({
  as,
  display,
  children,
  margin,
  marginTop,
  marginBottom,
  marginLeft,
  marginRight,
  m,
  mt,
  mb,
  ml,
  mr,
  mx,
  my,
  padding,
  paddingTop,
  paddingBottom,
  paddingLeft,
  paddingRight,
  p,
  pt,
  pb,
  pr,
  pl,
  px,
  py,
  printHidden,
  printVisible,
  hidden,
  xsUpHidden,
  smUpHidden,
  mdUpHidden,
  lgUpHidden,
  xlUpHidden,
  xsHidden,
  smHidden,
  mdHidden,
  lgHidden,
  xlHidden,
  className,
  "aria-expanded": ariaExpanded,
  ...props
}, ref) {
  const classNames = className?.split(" ") || [];
  let applyBasePropsToWrapper = true;
  const basePropToClassName = basePropGenerator({
    display,
    margin,
    marginTop,
    marginBottom,
    marginLeft,
    marginRight,
    m,
    mt,
    mb,
    ml,
    mr,
    mx,
    my,
    padding,
    paddingTop,
    paddingBottom,
    paddingLeft,
    paddingRight,
    p,
    pt,
    pb,
    pr,
    pl,
    px,
    py,
    printHidden,
    printVisible,
    hidden,
    xsUpHidden,
    smUpHidden,
    mdUpHidden,
    lgUpHidden,
    xlUpHidden,
    xsHidden,
    smHidden,
    mdHidden,
    lgHidden,
    xlHidden
  });
  if (typeof children === "string") {
    children = [children];
  }
  if (Array.isArray(children)) {
    const textClassNames = classNames?.map((className2) => `${className2}__text`).join(" ");
    children = children.map((child, index) => {
      if (Array.isArray(child)) {
        return child.map((child2, index2) => {
          if (typeof child2 === "string") {
            return /* @__PURE__ */ React.createElement(Text, { key: index2, className: textClassNames }, child2);
          }
          return child2;
        });
      } else if (typeof child === "string") {
        if (as && textHtmlTags.includes(as)) {
          applyBasePropsToWrapper = false;
        }
        return /* @__PURE__ */ React.createElement(
          Text,
          {
            key: index,
            className: applyBasePropsToWrapper ? textClassNames : `${textClassNames} ${basePropToClassName}`,
            ...props.onClick && {
              onPress: props.onClick
            }
          },
          child
        );
      }
      return child;
    });
  }
  const Component = useMemo(() => {
    const C = mapping[as] || View;
    if (classNames.find(
      (className2) => className2.match(/__wrapper|__before|__after$/)
    )) {
      return wrap(C);
    }
    return C;
  }, [className]);
  Object.keys(props).forEach((k) => {
    if (k.startsWith("aria")) {
      if (BooleanMapper[props[k]] !== void 0) {
        props[k] = BooleanMapper[props[k]];
      }
    }
  });
  return /* @__PURE__ */ React.createElement(
    Component,
    {
      ...props,
      ref,
      "aria-expanded": ariaExpanded === "false" ? false : ariaExpanded === true ? true : void 0,
      className: applyBasePropsToWrapper ? `${basePropToClassName} ${className}` : className
    },
    children
  );
});
var index_native_default = Base;
export {
  Base,
  index_native_default as default
};
//# sourceMappingURL=index.native.js.map
