import clsx from "clsx";
const generateSpacingClasses = (prefix, spacing) => {
  if (typeof spacing === "object") {
    return {
      [`${prefix}-xs-${spacing?.xs}`]: spacing?.xs !== void 0,
      [`${prefix}-sm-${spacing?.sm}`]: spacing?.sm !== void 0,
      [`${prefix}-md-${spacing?.md}`]: spacing?.md !== void 0,
      [`${prefix}-lg-${spacing?.lg}`]: spacing?.lg !== void 0,
      [`${prefix}-xl-${spacing?.xl}`]: spacing?.xl !== void 0
    };
  } else if (spacing !== void 0) {
    return {
      [`${prefix}-${spacing}`]: true
    };
  }
  return {};
};
const basePropGenerator = ({
  display,
  margin,
  marginTop,
  marginBottom,
  marginLeft,
  marginRight,
  m,
  mt,
  mb,
  ml,
  mr,
  mx,
  my,
  padding,
  paddingTop,
  paddingBottom,
  paddingLeft,
  paddingRight,
  p,
  pt,
  pb,
  pr,
  pl,
  px,
  py,
  printHidden,
  printVisible,
  hidden,
  xsUpHidden,
  smUpHidden,
  mdUpHidden,
  lgUpHidden,
  xlUpHidden,
  xsHidden,
  smHidden,
  mdHidden,
  lgHidden,
  xlHidden
}) => {
  return clsx({
    [`ds-display-${display}`]: display !== void 0,
    ...generateSpacingClasses("ds-m", m ?? margin),
    ...generateSpacingClasses("ds-mt", mt ?? marginTop),
    ...generateSpacingClasses("ds-mb", mb ?? marginBottom),
    ...generateSpacingClasses("ds-mr", mr ?? marginRight),
    ...generateSpacingClasses("ds-ml", ml ?? marginLeft),
    ...generateSpacingClasses("ds-mx", mx),
    ...generateSpacingClasses("ds-my", my),
    ...generateSpacingClasses("ds-p", p ?? padding),
    ...generateSpacingClasses("ds-pt", pt ?? paddingTop),
    ...generateSpacingClasses("ds-pb", pb ?? paddingBottom),
    ...generateSpacingClasses("ds-pr", pr ?? paddingRight),
    ...generateSpacingClasses("ds-pl", pl ?? paddingLeft),
    ...generateSpacingClasses("ds-px", px),
    ...generateSpacingClasses("ds-py", py),
    "ds-print-hidden": !!printHidden,
    "ds-print-visible-block": printVisible === "block",
    "ds-print-visible-inline": printVisible === "inline",
    "ds-hidden": !!hidden,
    "ds-hidden-xs-up": !!xsUpHidden,
    "ds-hidden-sm-up": !!smUpHidden,
    "ds-hidden-md-up": !!mdUpHidden,
    "ds-hidden-lg-up": !!lgUpHidden,
    "ds-hidden-xl-up": !!xlUpHidden,
    "ds-hidden-xs": !!xsHidden,
    "ds-hidden-sm": !!smHidden,
    "ds-hidden-md": !!mdHidden,
    "ds-hidden-lg": !!lgHidden,
    "ds-hidden-xl": !!xlHidden
  });
};
export {
  basePropGenerator
};
//# sourceMappingURL=utils.js.map
