import React, { useContext, useMemo, useState } from "react";
import { View } from "react-native";
const WrapperContext = React.createContext(
  (cls) => {
    return cls;
  }
);
const Wrapper = React.memo(function Wrapper2({
  children
}) {
  const [className, setClassName] = useState("");
  return /* @__PURE__ */ React.createElement(WrapperContext.Provider, { value: setClassName }, /* @__PURE__ */ React.createElement(View, { className, focusable: false }, children));
});
Wrapper.displayName = "Wrapper";
const wrap = (Component) => {
  const WrappedComponent = React.forwardRef(function InnerComponent({ className, onBlur, onFocus, ...props }, ref) {
    const setClassName = useContext(WrapperContext);
    const wrapperClassNames = [];
    const beforeClassNames = [];
    const afterClassNames = [];
    const focusedWrapperClassNames = [];
    const classNames = useMemo(
      () => (className?.split(" ") || []).filter((cls) => {
        if (cls.endsWith("__wrapper")) {
          wrapperClassNames.push(cls);
          focusedWrapperClassNames.push(`${cls}--focus`);
          return false;
        } else if (cls.endsWith("__before")) {
          beforeClassNames.push(cls);
          return false;
        } else if (cls.endsWith("__after")) {
          afterClassNames.push(cls);
          return false;
        }
        return true;
      }),
      [className]
    );
    return /* @__PURE__ */ React.createElement(React.Fragment, null, beforeClassNames.length ? /* @__PURE__ */ React.createElement(View, { focusable: false, className: beforeClassNames.join(" ") }) : "", /* @__PURE__ */ React.createElement(
      Component,
      {
        ref,
        onFocus: (e) => {
          setClassName(focusedWrapperClassNames.join(" "));
          if (onFocus) onFocus(e);
        },
        onBlur: (e) => {
          setClassName(wrapperClassNames.join(" "));
          if (onBlur) onBlur(e);
        },
        className: classNames.join(" "),
        ...props
      }
    ), afterClassNames.length ? /* @__PURE__ */ React.createElement(View, { focusable: false, className: afterClassNames.join(" ") }) : "");
  });
  return React.forwardRef(function Wrapped(props, ref) {
    const children = useMemo(
      () => /* @__PURE__ */ React.createElement(WrappedComponent, { ...props, ref }),
      []
    );
    return /* @__PURE__ */ React.createElement(Wrapper, null, children);
  });
};
export {
  wrap
};
//# sourceMappingURL=wrap.native.js.map
