import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
export interface ButtonProps extends BaseProps<'button'> {
    /**
     * color is optional.
     * 'primary' color is used for the main call to action on a page.
     * 'secondary' color is used for secondary calls to action on a page.
     * 'warning' color is used to make users think carefully before they use them.
     * The default value is 'primary'.
     * @value 'primary'
     * @value 'secondary'
     * @value 'warning'
     * @default 'primary'
     */
    color?: 'primary' | 'secondary' | 'warning';
    /**
     * variant is optional.
     * @value 'link'
     * @value 'button'
     * @default 'button'
     */
    variant?: 'link' | 'button';
    /**
     * dense is optional.
     * @value true Button will be dense.
     * @value false
     * @default false
     */
    dense?: boolean;
}
/**
 * Use the Button component to help users carry out an action.
 */
export declare const Button: React.ForwardRefExoticComponent<Omit<ButtonProps, "ref"> & React.RefAttributes<HTMLButtonElement>>;
export default Button;
