import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
export interface CardProps extends BaseProps<'div'> {
    /**
     * By default, we recommend using Cards without border style. Card border increases the contrast to its background.
     * divider
     * `variant` property is optional.
     * @value 'border'
     * @value 'divider'
     * @value 'border-top'
     */
    variant?: 'border' | 'divider' | 'border-top';
    /**
     *borderColor property is optional and it is used to set the color of the Card's border.
     *
     *
     * @value 'light'
     * @value 'dark'
     */
    borderColor?: 'light' | 'dark';
    /**
     *callToAction property is optional and it is used to set the content of the Card clickable.
     *
     *
     * @value true
     * @value false
     */
    callToAction?: boolean;
    /**
     * dense is optional.
     * @value true Card will be dense.
     * @value false
     * @default false
     * */
    dense?: boolean;
    /**
     * fullHeight is optional.
     * @value true Card will be have it's full height.
     * @value false
     * @default false
     * */
    fullHeight?: boolean;
}
/**
 * Cards can be used to divide and organise interface content for better understandability and readability.
 * Cards can help your users to scan through vast amounts of information quicker.
 * Use Card as parent component to wrap CardHeading, CardContent and CartAction components
 */
export declare const Card: React.ForwardRefExoticComponent<Omit<CardProps, "ref"> & React.RefAttributes<HTMLDivElement>>;
export default Card;
