import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
export interface DrawerProps extends BaseProps<'div'> {
    /**
     * open is optional.
     * This declares if the drawer is open at small screens.
     * @value true
     * @value false
     */
    open?: boolean;
    /**
     * direction is optional.
     * Add the direction of the drawer, when this is open at mobile view.
     * The default value is 'left'.
     * @value 'right'
     * @value 'left'
     * @default 'left'
     */
    direction?: 'right' | 'left';
    /**
     * upRelative is optional.
     * This declares if the drawer is visible at what screens in a relative position.
     * If not relative, it will be a drawer.
     * The default value is never.
     * @value 'sm' The drawer will be visible and relative at small screens and up
     * @value 'md' The drawer will be visible and relative at medium screens and up
     * @value 'lg' The drawer will be visible and relative at large screens and up
     * @value 'never' The drawer will never have relative position in the page
     * @default 'never'
     */
    upRelative?: 'sm' | 'md' | 'lg' | 'never';
    /**
     * bgColor is optional.
     * This defines the background color of the drawer.
     * @value 'base'
     * @value 'secondary'
     * @default 'base'
     */
    bgColor?: 'base' | 'secondary';
}
/**
 * Drawer can be used to provide access to destinations and app functionality.
 * It can either be permanently on-screen or controlled by a navigation menu icon.
 */
export declare const Drawer: React.ForwardRefExoticComponent<Omit<DrawerProps, "ref"> & React.RefAttributes<HTMLDivElement>>;
export default Drawer;
