import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
export interface DropdownButtonProps extends BaseProps<'summary'> {
    /**
     * color is optional.
     * 'primary' color gives DropdownButton the primary green color.
     * 'secondary' color gives DropdownButton the secondary gray color.
     * 'warning' color gives DropdownButton the warning red color.
     * The default value is 'primary'.
     * @value 'primary'
     * @value 'secondary'
     * @value 'warning'
     * @default 'primary'
     */
    color?: 'primary' | 'secondary' | 'warning';
    /**
     * variant is optional.
     * variant prop changes DropdownButton to button or link.
     * @value 'link'
     * @value 'button'
     * @default 'button'
     */
    variant?: 'link' | 'button';
    /**
     * arrow is optional.
     * arrow prop adds checkIcon component inside DropdownButton.
     * arrow prop is false by default
     * @value true
     * @value false
     * @default false
     */
    arrow?: boolean;
    /**
     * underline is optional.
     * Use this prop when you want to use Dropdown button as \<th\> header in sorted table.
     * @value true
     * @value false
     */
    underline?: boolean;
}
/**
 * DropdownButton it should be inside the Dropdown and it is used for opening or closing dropdown.
 */
export declare const DropdownButton: React.ForwardRefExoticComponent<Omit<DropdownButtonProps, "ref"> & React.RefAttributes<HTMLElement>>;
export default DropdownButton;
