import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
type GridValues = 'auto' | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12;
type SpacingValues = 1 | 2 | 3 | 4 | 5 | 6 | 8 | 10 | 11 | 12;
interface SpacingMediaValues {
    xs?: SpacingValues;
    sm?: SpacingValues;
    md?: SpacingValues;
    lg?: SpacingValues;
    xl?: SpacingValues;
}
export interface GridProps extends BaseProps<'div' | 'aside' | 'main'> {
    /**
     * If true, the component will have the flex container behavior. You should be wrapping items with a container.
     * @value true
     * @value false
     * @default false
     */
    container?: boolean;
    /**
     * @value true
     * @value false
     * @default true
     */
    item?: boolean;
    /**
     * @value true
     * @value false
     */
    inline?: boolean;
    /**
     * Defines the space between the type item components. It can only be used on a type container component.
     * @value 1
     * @value 2
     * @value 4
     * @value 6
     * @value 8
     * @value 10
     * @value 12
     * @value object
     * @default undefined
     */
    spacing?: SpacingValues | SpacingMediaValues;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12).
     * If 'auto', the grid item's width matches its content.
     * If it's not set, the prop is ignored.
     * The value is applied for all the screen sizes with the lowest priority.
     */
    xs?: GridValues;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12).
     * If 'auto', the grid item's width matches its content.
     * If it's not set, the prop is ignored.
     * The value is applied for the sm breakpoint and wider screens if not overridden.
     */
    sm?: GridValues;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12).
     * If 'auto', the grid item's width matches its content.
     * If it's not set, the prop is ignored.
     * The value is applied for the md breakpoint and wider screens if not overridden.
     */
    md?: GridValues;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12).
     * If 'auto', the grid item's width matches its content.
     * If it's not set, the prop is ignored.
     * The value is applied for the lg breakpoint and wider screens if not overridden.
     */
    lg?: GridValues;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12).
     * If 'auto', the grid item's width matches its content.
     * If it's not set, the prop is ignored.
     * The value is applied for the xl breakpoint and wider screens.
     */
    xl?: GridValues;
}
/**
 * Grid is used to arrange other components in complex grid configurations of rows and columns.
 */
export declare const Grid: React.ForwardRefExoticComponent<Omit<GridProps, "ref"> & React.RefAttributes<HTMLElement>>;
export default Grid;
