import React from 'react';
import { TypographyProps } from '@digigov/react-core/Typography';
export interface HeadingProps extends TypographyProps {
    /**
     * size is optional. 'xl' is the default value.
     * Use 'xl' when this heading is the main page title.
     * @value 'xl'
     * @value 'lg'
     * @value 'md'
     * @value 'sm'
     * @default 'xl'
     */
    size?: 'xl' | 'lg' | 'md' | 'sm' | 'xs';
    /**
     * element is optional. 'h1' is the default value.
     * Use 'h1' when this heading is the main page title.
     */
    element?: HeadingHTMLElements;
    /**
     * breakWords is optional. false is the default value.
     * Use true when you want to break words.
     */
    breakWords?: boolean;
}
export type HeadingHTMLElements = 'h1' | 'h2' | 'h3' | 'h4' | 'h5';
/**
 * Heading component is used to place a title in a the page.
 * Heading component must be wrapped inside Main component.
 */
export declare const Heading: React.ForwardRefExoticComponent<Omit<HeadingProps, "ref"> & React.RefAttributes<HTMLHeadingElement>>;
export default Heading;
