import React from 'react';
import { TypographyProps } from '@digigov/react-core/Typography';
export interface HintProps extends TypographyProps {
    /**
     * breakWords is optional. false is the default value.
     * Use true when you want to break words.
     */
    breakWords?: boolean;
    /**
     * size is optional.
     * @value 'lg' Use it when a lg text is an introductory paragraph that you can use at the top of a page to summarize the content.
     * @value 'md' The majority of your body should use the standard 'md' size.
     * @value 'sm' Use it sparingly to make your text font size smaller: 16px on larger screens and 14px on smaller screens.
     * @default 'md'
     */
    size?: 'lg' | 'md' | 'sm';
}
/**
 * Hint component can be used in form pages and it gives an extra hint description to the form.
 */
export declare const Hint: React.ForwardRefExoticComponent<Omit<HintProps, "ref"> & React.RefAttributes<HTMLParagraphElement>>;
export default Hint;
