import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
export interface ModalContainerProps extends BaseProps<'div'> {
    /**
     * @value true
     * @value false
     */
    open?: boolean;
    /**
     * dense is optional.
     * @value true ModalContainer and its children will be dense.
     * @value false
     * @default false
     */
    dense?: boolean;
    /**
     * gaps is optional.
     * @value false there will be no extra gaps among children components.
     * @value true
     * @default true
     */
    gaps?: boolean;
}
/**
 * Modals can be used to open a pop-up dialog box and provide critical information
 * or ask for a decision. Modals disable all app functionality when they appear, and
 * remain on screen until confirmed, dismissed, or a required action has been taken
 * Use Modal as parent component to wrap ModalHeading, ModalText and ModalAction components
 */
export declare const ModalContainer: React.ForwardRefExoticComponent<Omit<ModalContainerProps, "ref"> & React.RefAttributes<HTMLDivElement>>;
export default ModalContainer;
