import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
export interface NavProps extends BaseProps<'nav'> {
    /**
     * open is optional.
     * use this prop to control the navigation's visibility when it's a drawer.
     * @value true
     * @value false
     * @default false
     */
    open?: boolean;
    /**
     * border is optional.
     * border prop contains border-bottom styling.
     * @value true
     * @value false
     * @default true
     */
    border?: boolean;
    /**
     * drawer is optional.
     * drawer prop allows element to be positioned relative to the viewport.
     * Use this prop only if you want to implement responsive drawer navigation and you have a button to toggle the drawer open and closed.
     * @value 'never' the navigation will never be drawer
     * @value 'smDown' the navigation will be drawer on small screens only
     * @value 'mdDown' the navigation will be drawer on medium screens and below
     * @value 'lgDown' the navigation will be drawer on large screens and below
     * @value 'always' the navigation will be drawer on all screen sizes
     * @default 'never'
     */
    drawer?: 'never' | 'smDown' | 'mdDown' | 'lgDown' | 'always';
    /**
     * onClose makes a CloseButton component visible when the Nav is drawer.
     * Use this prop to close the drawer when close button is clicked, passing a callback function.
     * Make sure that the drawer prop is not 'never'.
     */
    onClose?: (e: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
    /**
     * closeButtonLabel is optional.
     * Use this prop to add text beside the close icon. For example: 'Κλείσιμο'.
     */
    closeButtonLabel?: string;
}
/**
 * Nav is mainly used under the Header.
 * This is a wrapper for the NavList component.
 */
export declare const Nav: React.ForwardRefExoticComponent<Omit<NavProps, "ref"> & React.RefAttributes<HTMLElement>>;
export default Nav;
