import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
export interface StackProps extends BaseProps<'div'> {
    /**
     * direction is optional. Set to control the direction of flex items.
     */
    direction?: 'row' | 'row-reverse' | 'column' | 'column-reverse';
    /**
     * justifyContent is optional. Set to control how items are positioned along Stack's main axis .
     */
    justifyContent?: 'flex-start' | 'flex-end' | 'center' | 'space-between' | 'space-around' | 'space-evenly';
    /**
     * alignItems is optional. Set to control how items are positioned along Stack's cross axis.
     */
    alignItems?: 'stretch' | 'flex-start' | 'flex-end' | 'center' | 'baseline';
    /**
     * alignContent is optional. Set to control how rows are positioned in multi-row Stack container.
     */
    alignContent?: 'flex-start' | 'flex-end' | 'center' | 'space-between' | 'space-around' | 'space-evenly';
    /**
     * spacing is optional. Set to the number you want the space to be.
     */
    spacing?: SpacingValues | SpacingMediaValues;
    /**
     * flexWrap is optional. The default value is 'wrap'.
     */
    flexWrap?: 'wrap' | 'nowrap';
}
type SpacingValues = 1 | 2 | 3 | 4 | 5 | 6 | 8 | 10 | 11 | 12;
interface SpacingMediaValues {
    xs?: SpacingValues;
    sm?: SpacingValues;
    md?: SpacingValues;
    lg?: SpacingValues;
    xl?: SpacingValues;
}
/**
 * ...
 */
export declare const Stack: React.ForwardRefExoticComponent<Omit<StackProps, "ref"> & React.RefAttributes<HTMLDivElement>>;
export default Stack;
