import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
export interface TableHeadCellProps extends BaseProps<'th'> {
    /**
     * dataType is optional.
     * Use numeric value prop when comparing columns of numbers, align the numbers to the right in table cells.
     * Default value is text which aligns texts to the center
     * @value 'text'
     * @value 'numeric'
     * @default 'text'
     */
    dataType?: 'text' | 'numeric';
    /**
     * width is optional.
     * Use width prop to define a custom width in your component.
     * @value '25%';
     * @value '33.3%';
     * @value '50%';
     * @value '66.6%';
     * @value '75%';
     * @value '100%';
     * @value 'full';
     */
    width?: '25%' | '33.3%' | '50%' | '66.6%' | '75%' | '100%' | 'full';
}
/**
 * Use TableHeadCell inside the Table component to provide the header row and/or column of the table.
 */
export declare const TableHeadCell: React.ForwardRefExoticComponent<Omit<TableHeadCellProps, "ref"> & React.RefAttributes<HTMLTableCellElement>>;
export default TableHeadCell;
