import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
export interface TextInputProps extends BaseProps<'input'> {
    /**
     * maxWidth is optional.
     * @value '2-char';
     * @value '3-char';
     * @value '4-char';
     * @value '5-char';
     * @value '10-char';
     * @value '20-char';
     */
    maxWidth?: '2-char' | '3-char' | '4-char' | '5-char' | '10-char' | '20-char';
    /**
     * width is optional.
     * Use width prop to define a custom width in your component.
     * @value '25%';
     * @value '33.3%';
     * @value '50%';
     * @value '66.6%';
     * @value '75%';
     * @value '100%';
     * @value 'full';
     */
    width?: '25%' | '33.3%' | '50%' | '66.6%' | '75%' | '100%' | 'full';
    /**
     * error is optional. The default value is false.
     * Use this prop when there is an error at the input.
     * @value true
     * @value false
     */
    error?: boolean;
    /**
     * dense is optional.
     * @value true TextInput will be dense.
     * @value false
     * @default false
     */
    dense?: boolean;
}
/**
 * TextInput component when you need to let users enter text that’s no
 * longer than a single line, such as their name or phone number.
 */
export declare const TextInput: React.ForwardRefExoticComponent<Omit<TextInputProps, "ref"> & React.RefAttributes<HTMLInputElement>>;
export default TextInput;
