import React from 'react';
import clsx from 'clsx';
import Container, { ContainerProps } from '@digigov/react-core/Container';

export interface AdminContainerProps extends Omit<ContainerProps, 'grid'> {
  /**
   * grid is optional. Set to false if you don't need grid layout.
   * @value true
   * @value false
   * @default true
   */
  grid?: boolean;
}
/**
 * AdminContainer is a wrapper for the content of the page
 * Use AdminContainer inside AdminLayout component
 */
export const AdminContainer = React.forwardRef<
  HTMLDivElement,
  AdminContainerProps
>(function AdminContainer({ grid = true, className, children, ...props }, ref) {
  return (
    <Container
      ref={ref}
      fullWidth={true}
      grid={grid}
      className={clsx(className, {
        'ds-admin-container': true,
      })}
      {...props}
    >
      {children}
    </Container>
  );
});

export default AdminContainer;
