import React from 'react';
import clsx from 'clsx';
import Grid, { GridProps } from '@digigov/react-core/Grid';

export interface AdminTopSectionProps extends GridProps {
  /**
   * color is optional.
   * 'primary' color gives AdminTopSection the default color.
   * @value primary
   * @value secondary
   * @default primary
   * */
  color?: 'primary' | 'secondary';
  /**
   * border is optional.
   * border prop adds border to AdminTopSection.
   * @value true
   * @value false
   */
  border?: boolean;
}
/**
 * Use  AdminTopSection component inside AdminContainer component to seperate content in
 * 1 to 12 individual equal spaces
 */
export const AdminTopSection = React.forwardRef<
  HTMLDivElement,
  AdminTopSectionProps
>(function AdminTopSection(
  { color = 'primary', border, className, children, ...props },
  ref
) {
  return (
    <Grid
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-admin-top-section': true,
        'ds-admin-top-section--secondary': color === 'secondary',
        'ds-admin-top-section--border': border,
      })}
      {...props}
    >
      {children}
    </Grid>
  );
});

export default AdminTopSection;
