import React from 'react';
import clsx from 'clsx';
import Grid, { GridProps } from '@digigov/react-core/Grid';

export interface AsideProps extends GridProps {
  /**
   * sticky is optional.
   * If true, the Aside will be sticky.
   * @value true
   * @value false
   * @default true
   */
  sticky?: boolean;
  /**
   * fullHeight is optional.
   * If true, the Aside will be full height.
   * This prop is useful when we want to place the BackToTop component inside the Aside component and show it at the bottom of the page.
   * @value true
   * @value false
   * @default false
   */
  fullHeight?: boolean;
}
/**
 * Use this inside the Container component for additional content.
 * that will be shown on the left one third of the page.
 */
export const Aside = React.forwardRef<HTMLElement, AsideProps>(function Aside(
  { className, sticky = true, fullHeight, children, ...props },
  ref
) {
  return (
    <Grid
      item
      xs={12}
      md={4}
      spacing={4}
      as="aside"
      ref={ref}
      className={clsx(className, {
        'ds-aside': true,
        'ds-aside--sticky': sticky,
        'ds-aside--full-height': fullHeight,
      })}
      {...props}
    >
      {children}
    </Grid>
  );
});

export default Aside;
