import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface AutoCompleteContainerProps extends BaseProps<'div'> {
  /**
   * width is optional.
   * Use width prop to define a custom width in your component.
   * @value '25%';
   * @value '33.3%';
   * @value '50%';
   * @value '66.6%';
   * @value '75%';
   * @value '100%';
   * @value 'full';
   */
  width?: '25%' | '33.3%' | '50%' | '66.6%' | '75%' | '100%' | 'full';
}
/**
 * AutoCompleteContainer is a wrapper for autocomplete element.
 * Use AutoCompleteContainer to wrap autocomplete elements.
 */
export const AutoCompleteContainer = React.forwardRef<
  HTMLDivElement,
  AutoCompleteContainerProps
>(function AutoCompleteContainer(
  { className, width, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-autocomplete__container': true,
        'ds-!-width-one-quarter': width === '25%',
        'ds-!-width-one-third': width === '33.3%',
        'ds-!-width-one-half': width === '50%',
        'ds-!-width-two-thirds': width === '66.6%',
        'ds-!-width-three-quarters': width === '75%',
        'ds-!-width-full': width === 'full',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default AutoCompleteContainer;
