import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
export interface AutoCompleteInputBaseProps extends BaseProps<'input'> {
  /**
   * isFocused is optional. The default value is false.
   * isFocused prop is used to focus the list element.
   * @value true
   * @value false
   */
  isFocused?: boolean;
}
/**
 * AutoCompleteInputBase component is used to display the value that the user is typing.
 *
 */
export const AutoCompleteInputBase = React.forwardRef<
  HTMLInputElement,
  AutoCompleteInputBaseProps
>(function AutoCompleteInputBase(
  { name, isFocused, className, ...props },
  ref
) {
  return (
    <Base
      as="input"
      type="text"
      name={name}
      ref={ref}
      className={clsx(className, {
        'ds-autocomplete__input': true,
        'ds-autocomplete__input--focused': isFocused,
      })}
      {...props}
    />
  );
});

export default AutoCompleteInputBase;
