import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface AutoCompleteMultipleInputContainerProps
  extends BaseProps<'div'> {
  open?: boolean;
  isFocused?: boolean;
  numberOfSelected?: 1 | 2 | 3 | 'all';
}
/**
 * Use AutoCompleteMultipleInputContainer to accept multiple values input.
 */
export const AutoCompleteMultipleInputContainer = React.forwardRef<
  HTMLDivElement,
  AutoCompleteMultipleInputContainerProps
>(function AutoCompleteMultipleInputContainer(
  { numberOfSelected = 'all', children, isFocused, className, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-autocomplete__multi-input-container': true,
        'ds-autocomplete__multi-input-container--focused': isFocused,
        [`ds-autocomplete__multi-input-container--${numberOfSelected}`]:
          typeof numberOfSelected === 'number',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default AutoCompleteMultipleInputContainer;
