import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface AutoCompleteResultListProps extends BaseProps<'ul'> {
  /**
   * isVisible is optional.
   * Use isVisible prop to make menu visible
   * default value is false.
   *
   * @value true
   * @value false
   * @default false
   */
  isVisible?: boolean;
}
/**
 * AutoCompleteResultList component is used for listing items.
 * This component must contain AutoCompleteResultListItem component.
 */
export const AutoCompleteResultList = React.forwardRef<
  HTMLUListElement,
  AutoCompleteResultListProps
>(function List({ isVisible = false, className, children, ...props }, ref) {
  return (
    <Base
      as="ul"
      ref={ref}
      className={clsx(className, {
        'ds-autocomplete__menu': true,
        'ds-autocomplete__menu--hidden': isVisible === false,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default AutoCompleteResultList;
