import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import { CaretIcon } from '@digigov/react-icons';

export interface BackLinkProps extends BaseProps<'a'> {}
/**
 * Use BackLink component to help users go back to the previous page in a multi-page transaction.
 */
export const BackLink = React.forwardRef<HTMLAnchorElement, BackLinkProps>(
  function BackLink(
    { href, printHidden = true, className, children, ...props },
    ref
  ) {
    return (
      <Base
        as="a"
        printHidden={printHidden}
        href={href}
        onClick={() => !href && window.history.back()}
        ref={ref}
        className={clsx(className, {
          'ds-back-link': true,
        })}
        tabIndex={0}
        {...props}
      >
        <CaretIcon direction={'left'} />
        {children}
      </Base>
    );
  }
);

export default BackLink;
