import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import { ArrowIcon } from '@digigov/react-icons';

export interface BackToTopLinkProps extends BaseProps<'a'> {}
/**
 * Use BackToTopLink component to help users go to the top of the page.
 */
export const BackToTopLink = React.forwardRef<
  HTMLAnchorElement,
  BackToTopLinkProps
>(function BackToTopLink(
  { printHidden = true, className, children, ...props },
  ref
) {
  return (
    <Base
      as="a"
      printHidden={printHidden}
      ref={ref}
      className={clsx(className, {
        'ds-back-to-top-link': true,
      })}
      tabIndex={0}
      {...props}
    >
      <ArrowIcon direction={'up'} marginRight={1} />
      {children}
    </Base>
  );
});

export default BackToTopLink;
