import React, {
  DetailedHTMLProps,
  InputHTMLAttributes,
  LegacyRef,
} from 'react';
import { TouchableOpacity, View } from 'react-native';

export type CheckboxInputProps = Omit<
  DetailedHTMLProps<InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>,
  'ref'
>;

export const CheckboxInput = React.forwardRef<
  HTMLInputElement,
  CheckboxInputProps
>(function CheckboxInput({ checked, value, onChange, ...props }, ref) {
  const handlePress = () => {
    if (onChange) {
      const syntheticEvent = {
        currentTarget: {
          value,
          checked: !checked,
        },
      } as React.ChangeEvent<HTMLInputElement>;
      onChange(syntheticEvent);
    }
  };
  return (
    // @ts-ignore
    <TouchableOpacity
      ref={ref as LegacyRef<TouchableOpacity>}
      onPress={handlePress}
      {...props}
    >
      {checked && <View className="ds-checkboxes__input--checked" />}
    </TouchableOpacity>
  );
});

export default CheckboxInput;
