import React, {
  ButtonHTMLAttributes,
  DetailedHTMLProps,
  useContext,
} from 'react';
import { Pressable } from 'react-native';
// @ts-expect-error - `@digigov/form` is to be removed as a dependency
import { FormContext } from '@digigov/form/FormContext';

// TODO: Fix `ButtonProps` type
export type ButtonProps = Omit<
  DetailedHTMLProps<ButtonHTMLAttributes<HTMLButtonElement>, HTMLButtonElement>,
  'ref'
>;

export const FormButton = React.forwardRef<unknown, ButtonProps>(
  function FormButton({ onClick, ...props }, ref) {
    const formContext = useContext(FormContext);
    return (
      <CompatButton
        ref={ref}
        {...props}
        onClick={() => {
          if (onClick) onClick({} as React.MouseEvent<HTMLButtonElement>);
          if (props.type) formContext?.[props.type]();
        }}
      />
    );
  }
);

// TODO: Fix `ref` type
export const CompatButton = React.forwardRef<unknown, ButtonProps>(
  function CompatButton({ onClick, ...props }, ref) {
    return (
      <Pressable
        onPress={onClick as any}
        ref={ref as any}
        hitSlop={10}
        {...(props as any)}
      />
    );
  }
);

export const Button = React.forwardRef<unknown, ButtonProps>(
  function Button(props, ref) {
    if (props.type && ['submit', 'reset'].includes(props.type)) {
      return <FormButton ref={ref} {...props} />;
    }
    return <CompatButton ref={ref} {...props} />;
  }
);
