import React, {
  useEffect,
  useState,
  Children,
  DetailedHTMLProps,
  DetailsHTMLAttributes,
} from 'react';
import { View, Text, TouchableOpacity, StyleSheet } from 'react-native';

type HTMLElementProps = Omit<
  DetailedHTMLProps<
    DetailsHTMLAttributes<HTMLDetailsElement>,
    HTMLDetailsElement
  >,
  'ref'
> & {
  closeIcon?: string;
  openIcon?: string;
  placement?: 'before' | 'after';
};

const CompatDetails = ({
  children,
  open = false,
  placement,
  closeIcon,
  openIcon,
  ...props
}: HTMLElementProps) => {
  const [isExpanded, setIsExpanded] = useState(open);

  useEffect(() => {
    setIsExpanded(open);
  }, [open]);

  const toggleExpand = () => {
    setIsExpanded(!isExpanded);
  };

  const [summaryContent, ...detailsContent] = Children.toArray(children);

  const toggleIcon =
    closeIcon && openIcon ? (
      <Text>{isExpanded ? openIcon : closeIcon}</Text>
    ) : null;

  return (
    // TODO: Fix `props` type
    // @ts-expect-error - `props` type is not compatible with `View` props
    <View {...props}>
      <TouchableOpacity onPress={toggleExpand} style={styles.summaryContainer}>
        {placement === 'before' && toggleIcon}
        {summaryContent}
        {placement === 'after' && toggleIcon}
      </TouchableOpacity>
      {isExpanded && <View>{detailsContent}</View>}
    </View>
  );
};

const styles = StyleSheet.create({
  summaryContainer: {
    flexDirection: 'row',
    alignItems: 'center',
  },
});

export default CompatDetails;
