import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface BlockquoteProps extends BaseProps<'blockquote'> {
  /**
   * dense is optional.
   * @value true Blockquote will be dense.
   * @value false
   * @default false
   * */
  dense?: boolean;
}
/**
 * Use Blockquote to differentiate a block of text from the content that surrounds it.
 */
export const Blockquote = React.forwardRef<HTMLElement, BlockquoteProps>(
  function Blockquote({ className, dense, children, ...props }, ref) {
    return (
      <Base
        as="blockquote"
        ref={ref}
        className={clsx(className, {
          'ds-blockquote': true,
          'ds-blockquote--dense': dense,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Blockquote;
