import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface BreadcrumbsProps extends BaseProps<'div'> {}
/**
 * Use Breadcrumbs component when you need to help users understand and move between the multiple levels of a website.
 * The breadcrumb should start with your ‘home’ page and end with the parent section of the current page.
 */
export const Breadcrumbs = React.forwardRef<HTMLDivElement, BreadcrumbsProps>(
  function Breadcrumbs({ className, children, ...props }, ref) {
    return (
      <Base
        as="nav"
        aria-label="Breadcrumb"
        ref={ref}
        className={clsx(className, {
          'ds-breadcrumbs': true,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Breadcrumbs;
