import React from 'react';
import clsx from 'clsx';
import Link, { LinkBaseProps } from '@digigov/react-core/LinkBase';

export interface BreadcrumbsListItemLinkProps extends LinkBaseProps {}
/**
 * BreadcrumbsListItemLink creates an anchor link to navigate in different
 * parts of the breadcrumbs.
 * It should be used inside BreadcrumbsListItem as children component. This is
 * the default link component for the BreadcrumbsListItem and it uses the LinkBase
 * component from `@digigov/react-core`. In case you need to use a different Link
 * component from a framework or a custom router, use `@digigov/ui/navigation/BreadcrumbsListItemLink` instead.
 */
export const BreadcrumbsListItemLink = React.forwardRef<
  HTMLAnchorElement,
  BreadcrumbsListItemLinkProps
>(function BreadcrumbsListItemLink({ href, className, children }, ref) {
  return (
    <Link
      href={href}
      defaultStyle={false}
      className={clsx(className, {
        'ds-breadcrumbs__link': true,
        'ds-breadcrumbs__link--inactive': href === undefined,
      })}
      ref={ref}
    >
      {children}
    </Link>
  );
});

export default BreadcrumbsListItemLink;
