import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface ButtonProps extends BaseProps<'button'> {
  /**
   * color is optional.
   * 'primary' color is used for the main call to action on a page.
   * 'secondary' color is used for secondary calls to action on a page.
   * 'warning' color is used to make users think carefully before they use them.
   * The default value is 'primary'.
   * @value 'primary'
   * @value 'secondary'
   * @value 'warning'
   * @default 'primary'
   */
  color?: 'primary' | 'secondary' | 'warning';
  /**
   * variant is optional.
   * @value 'link'
   * @value 'button'
   * @default 'button'
   */
  variant?: 'link' | 'button';
  /**
   * dense is optional.
   * @value true Button will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
}
/**
 * Use the Button component to help users carry out an action.
 */
export const Button = React.forwardRef<HTMLButtonElement, ButtonProps>(
  function Button(
    {
      color = 'primary',
      variant = 'button',
      dense,
      disabled,
      printHidden = true,
      className,
      children,
      ...props
    },
    ref
  ) {
    return (
      <Base
        as="button"
        disabled={disabled}
        printHidden={printHidden}
        ref={ref}
        className={clsx(className, {
          'ds-link': variant === 'link',
          'ds-btn': variant === 'button',
          'ds-btn--dense': dense,
          'ds-btn-primary': variant === 'button' && color === 'primary',
          'ds-btn-secondary': variant === 'button' && color === 'secondary',
          'ds-btn-warning': variant === 'button' && color === 'warning',
          'ds-btn--disabled': variant === 'button' && disabled,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Button;
