import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface ButtonLinkProps extends BaseProps<'a'> {
  /**
   * color is optional.
   * 'primary' color is used for the main call to action on a page.
   * 'secondary' color is used for secondary calls to action on a page.
   * 'warning' color is used to make users think carefully before they use them.
   * The default value is 'primary'.
   * @value 'primary'
   * @value 'secondary'
   * @value 'warning'
   * @default 'primary'
   */
  color?: 'primary' | 'secondary' | 'warning';

  /**
   * dense is optional.
   * @value true Button will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
}
/**
 * Use the Button component to help users carry out an action.
 */
export const ButtonLink = React.forwardRef<HTMLAnchorElement, ButtonLinkProps>(
  function ButtonLink(
    { color = 'primary', dense, className, children, ...props },
    ref
  ) {
    return (
      <Base
        as="a"
        ref={ref}
        className={clsx(className, {
          'ds-btn': true,
          'ds-btn--dense': dense,
          'ds-btn-primary': color === 'primary',
          'ds-btn-secondary': color === 'secondary',
          'ds-btn-warning': color === 'warning',
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default ButtonLink;
