import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface CheckboxProps extends BaseProps<'div'> {
  /**
   * layout is optional.
   * 'horizontal' places the CheckboxItems in one line.
   * 'horizontal' should be used or only two CheckboxItems with limited text.
   * @value 'vertical'
   * @value 'horizontal'
   * @default 'vertical'
   */
  layout?: 'horizontal' | 'vertical';
  /**
   * dense is optional.
   * @value true Checkboxes will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
}
/**
 * Details for the Checkbox.
 * Checkbox component allow the user to select one or more items from a set.
 * It takes CheckboxItem as children
 */
export const Checkbox = React.forwardRef<HTMLDivElement, CheckboxProps>(
  function Checkbox({ layout, dense, className, children, ...props }, ref) {
    return (
      <Base
        as="div"
        ref={ref}
        className={clsx(className, {
          'ds-checkboxes': true,
          'ds-checkboxes--horizontal': layout === 'horizontal',
          'ds-checkboxes--dense': dense,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Checkbox;
