import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import FieldContainer from '@digigov/react-core/FieldContainer';
import LabelContainer from '@digigov/react-core/LabelContainer';

export interface CheckboxConditionalProps extends BaseProps<'div'> {}
/**
 * CheckboxConditional asks the user a related question when they select a particular checkbox,
 * so they only see the question when it’s relevant to them.
 * CheckboxConditional must be used inside Checkbox component
 */
export const CheckboxConditional = React.forwardRef<
  HTMLDivElement,
  CheckboxConditionalProps
>(function CheckboxConditional({ className, children, ...props }, ref) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-checkboxes__conditional': true,
      })}
      {...props}
    >
      <FieldContainer>
        <LabelContainer>{children}</LabelContainer>
      </FieldContainer>
    </Base>
  );
});

export default CheckboxConditional;
