import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import { CloseIcon } from '@digigov/react-icons';

export interface ChipProps extends BaseProps<'li'> {
  /**

  */
  onDelete?: (e: React.MouseEvent<SVGSVGElement, MouseEvent>) => void;
}
/**
 * Chips can be used to represent small blocks of information.
 * Chip component must be inside ChipContainer component.
 */
export const Chip = React.forwardRef<HTMLLIElement, ChipProps>(function Chip(
  { className, onDelete, onClick, children, ...props },
  ref
) {
  return (
    <Base
      as="li"
      ref={ref}
      className={clsx(className, {
        'ds-chip': true,
        'ds-chip--deletable': !!onDelete,
      })}
      {...props}
      onClick={onClick}
    >
      <Base
        as="div"
        role={onClick && 'button'}
        tabIndex={onClick && 0}
        className="ds-chip__content"
      >
        {children}
        {onDelete && (
          <CloseIcon
            onClick={(e) => {
              e.stopPropagation();
              onDelete(e);
            }}
          />
        )}
      </Base>
    </Base>
  );
});

export default Chip;
