import React from 'react';
import clsx from 'clsx';
import Typography, { TypographyProps } from '@digigov/react-core/Typography';
export interface CodeProps extends TypographyProps {
  /**
   * size is optional.
   * @value 'lg' Use it when a lg text is an introductory paragraph that you can use at the top of a page to summarize the content.
   * @value 'md' The majority of your body should use the standard 'md' size.
   * @value 'sm' Use it sparingly to make your text font size smaller: 16px on larger screens and 14px on smaller screens.
   * @default 'md'
   */
  color?: 'default' | 'info' | 'attribute' | 'string' | 'keyword' | 'name';
}
/**
 * Code component is used for text formatting.
 * If you need a paragraph, use the Paragraph component instead.
 */
export const Code = React.forwardRef<
  HTMLElement | HTMLParagraphElement,
  CodeProps
>(function Code({ color = 'default', className, children, ...props }, ref) {
  return (
    <Typography
      as="code"
      ref={ref}
      className={clsx(className, {
        'ds-code': true,
        'ds-code--attr': color === 'attribute',
        'ds-code--string': color === 'string',
        'ds-code--keyword': color === 'keyword',
        'ds-code--name': color === 'name',
      })}
      {...props}
    >
      {children}
    </Typography>
  );
});

export default Code;
