import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface CodeBlockHeaderProps extends BaseProps<'div'> {
  /**
   * justify prop is optional.
   * justify prop is used the justify-content style.
   * @value 'start' is used to place the header's content at the start.
   * @value 'end' is used to place the header's content at the end.
   * @value 'spaceBetween' is recommended for two items in header.
   * @default 'start'
   */
  justify?: 'start' | 'space-between' | 'end';
}
/**
 * CodeBlockHeader can be used as header inside the CodeBlockContainer.
 *
 */
export const CodeBlockHeader = React.forwardRef<
  HTMLDivElement,
  CodeBlockHeaderProps
>(function CodeBlockHeader(
  { className, justify = 'start', children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-code-block__header': true,
        [`ds-code-block__header--${justify}`]: justify !== undefined,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default CodeBlockHeader;
