import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface CopyToClipboardMessageProps extends BaseProps<'div'> {
  /**
   * enabled is a boolean prop passed from the CopyToClipboard component.
   * When it's true it shows the CopyToClipboardMessage component and it activates the animation that hides the component after 3s.
   * When it's false it resets the animations of the CopyToClipboardMessage.
   * @value true
   * @value false
   */
  enabled?: boolean;
}
/**
 * CopyToClipboardMessage is used to show a message that a text is being copied.
 * This component is used inside the CopyToClipboard component that lies inside the digigov/ui library
 */
export const CopyToClipboardMessage = React.forwardRef<
  HTMLDivElement,
  CopyToClipboardMessageProps
>(function CopyToClipboardMessage(
  { enabled, className, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-copy-to-clipboard__message': true,
        'ds-copy-to-clipboard--hidden': !enabled,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default CopyToClipboardMessage;
