import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface DetailsSummaryProps extends BaseProps<'summary'> {
  /*
   ** size is optional. Default value is 'md'.
   * @value 'md'
   * @value 'lg'
   */
  size?: 'md' | 'lg';
}
/**
 * Use this inside Details.DetailsSummary will be the text to click on.
 */
export const DetailsSummary = React.forwardRef<
  HTMLElement,
  DetailsSummaryProps
>(function DetailsSummary({ size, className, children, ...props }, ref) {
  return (
    <Base
      as="summary"
      ref={ref}
      className={clsx(className, {
        'ds-details__summary': true,
        'ds-details__summary--lg': size === 'lg',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default DetailsSummary;
