import React from 'react';
import clsx from 'clsx';
import CloseButton from '@digigov/react-core/CloseButton';
import Stack, { StackProps } from '@digigov/react-core/Stack';

export interface DrawerHeadingProps extends StackProps {
  /**
   * closeLabel is optional.
   * This declares the label of the close icon.
   * @default 'Κλείσιμο'
   */
  closeLabel?: string;
}
/**
 * Use DrawerHeading component inside Drawing
 * for menu heading title and close icon(for mobiles).
 */

export const DrawerHeading = React.forwardRef<
  HTMLDivElement,
  DrawerHeadingProps
>(function DrawerHeading(
  { className, children, onClick, closeLabel = 'Κλείσιμο', ...props },
  ref
) {
  return (
    <Stack
      direction="row"
      alignItems="baseline"
      className={clsx(className, {
        'ds-drawer__heading': true,
      })}
      ref={ref}
      {...props}
    >
      {children}
      <CloseButton onClick={(e) => onClick && onClick(e as any)}>
        {closeLabel}
      </CloseButton>
    </Stack>
  );
});

export default DrawerHeading;
