import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
export interface DropdownBaseProps extends BaseProps<'details'> {
  /**
   * align is optional. The default value is right.
   * align prop adds DropdownBaseContent right or left.
   * @value 'right'
   * @value 'left'
   * @default 'left'
   */
  align?: 'right' | 'left';
  /**
   * placement is optional. The default value is bottom.
   * placement prop adds DropdownBaseContent top or bottom.
   * @value 'top'
   * @value 'bottom'
   */
  placement?: 'top' | 'bottom';
  /**
   * disabled is optional. The default value is false.
   * disabled prop diables any action for DropdownBase component.
   * @value true
   * @value false
   */
  disabled?: boolean;
  /**
   * dense is optional.
   * @value true DropdownBase and its children will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
}
/**
 * DropdownBase is the main component for a dropdownBase.
 * Inside this component must be DropdownBaseButton and DropdownBaseContent components.
 */
export const DropdownBase = React.forwardRef<
  HTMLDetailsElement,
  DropdownBaseProps
>(function DropdownBase(
  { className, dense, children, align = 'left', placement, disabled, ...props },
  ref
) {
  return (
    <Base
      as="details"
      ref={ref}
      className={clsx(className, {
        'ds-dropdown': true,
        'ds-dropdown--right': align === 'right',
        'ds-dropdown--up': placement === 'top',
        'ds-dropdown--disabled': disabled,
        'ds-dropdown--dense': dense,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default DropdownBase;
