import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface ErrorMessageProps extends BaseProps<'p'> {}
/**
 * ErrorMessage is used to show an error message when there is a validation error.
 * In the error message explain what went wrong and how to fix it.
 * This component is placed below the FieldsetLegend and the Hint.
 */
export const ErrorMessage = React.forwardRef<
  HTMLParagraphElement,
  ErrorMessageProps
>(function ErrorMessage({ className, children, ...props }, ref) {
  return (
    <Base
      as="p"
      ref={ref}
      className={clsx(className, {
        'ds-error-message': true,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default ErrorMessage;
