import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
import NotificationBannerContainer from '@digigov/react-core/NotificationBannerContainer';
import NotificationBannerContent from '@digigov/react-core/NotificationBannerContent';
export interface ErrorSummaryProps extends BaseProps<'div'> {
  /**
   * dense is optional.
   * @value true ErrorSummary will be dense.
   * @value false
   * @default false
   * */
  dense?: boolean;
  /**
   * variant is optional.
   * variant error is used to change the color of the NotificationBannerContainer.
   * variant error-group is used to display red line on the left side of the component and exclamation mark icon with light red as background.
   * @value 'error'
   * @value 'error-group'
   * @default 'error'.
   */
  variant?: 'error' | 'error-group';
}
/**
 * Use this component at the top of a page to summarize any errors a user has made.
 */
export const ErrorSummary = React.forwardRef<HTMLDivElement, ErrorSummaryProps>(
  function ErrorSummary(
    { className, dense, children, variant = 'error', ...props },
    ref
  ) {
    return (
      <NotificationBannerContainer
        variant={variant}
        className={className}
        ref={ref}
        dense={dense}
        {...props}
      >
        <NotificationBannerContent variant={variant}>
          {children}
        </NotificationBannerContent>
      </NotificationBannerContainer>
    );
  }
);

export default ErrorSummary;
