import React from 'react';
import clsx from 'clsx';
import Grid, { GridProps } from '@digigov/react-core/Grid';

export interface FieldContainerProps extends GridProps {
  /**
   * error is optional.
   * @value true
   * @value false
   */
  error?: boolean;
}
/**
 * Field component wraps form components such as Checkbox TextInput TextArea etc.
 */
export const FieldContainer = React.forwardRef<
  HTMLDivElement,
  FieldContainerProps
>(function FieldContainer(
  { error, className, children, xs = 12, md, lg, xl, ...props },
  ref
) {
  return (
    <Grid
      ref={ref}
      className={clsx(className, {
        'ds-field': true,
        'ds-field--error': error,
      })}
      item
      xs={xs}
      md={md}
      lg={lg}
      xl={xl}
      {...props}
    >
      {children}
    </Grid>
  );
});

export default FieldContainer;
