import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface FieldsetLegendProps extends BaseProps<'legend'> {
  /**
   * size is optional. The default value is 'lg'
   * @value 'xl'
   * @value 'lg'
   * @value 'md'
   * @value 'sm'
   * @default 'lg'
   */
  size?: 'xl' | 'lg' | 'md' | 'sm';

  /**
   * heading is optional.
   * Add this prop if this Fieldset component is the only one in this page.
   * The default value is false.
   * @value true
   * @value false
   * @default false
   */
  heading?: boolean;
}
/**
 * FieldsetLegend component is the title within a Fieldset component.
 */
export const FieldsetLegend = React.forwardRef<
  HTMLLegendElement,
  FieldsetLegendProps
>(function FieldsetLegend(
  { size = 'lg', heading = false, className, children, ...props },
  ref
) {
  return (
    <Base
      as="legend"
      ref={ref}
      className={clsx(className, {
        'ds-fieldset__legend': true,
        [`ds-fieldset__legend--${size}`]: size !== undefined,
      })}
      {...(heading && { role: 'heading', 'aria-level': 1 })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default FieldsetLegend;
