import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface FileUploadProps extends BaseProps<'input'> {
  /**
   * hasFiles is optional.
   * @value true
   * @value false
   * @default false
   */
  hasFiles?: boolean;
}
/**
 * Details for the FileUpload.
 * FileUpload component is used for uploading files
 */
export const FileUpload = React.forwardRef<HTMLInputElement, FileUploadProps>(
  function FileUpload(
    { name, className, children, disabled, hasFiles = false, ...props },
    ref
  ) {
    return (
      <Base
        as="label"
        tabIndex={0}
        role="button"
        className={clsx(className, {
          'ds-label-file': true,
          'ds-btn': !hasFiles,
          'ds-btn-secondary': !hasFiles,
          'ds-link': hasFiles,
        })}
      >
        <Base
          as="input"
          ref={ref}
          type="file"
          name={name}
          disabled={disabled}
          className={clsx({
            'ds-file-input': true,
          })}
          {...props}
        />
        {children}
      </Base>
    );
  }
);

export default FileUpload;
