import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface FillableTextProps extends BaseProps<'blockquote'> {}
/**
 * Use FillableText component to display text that is connected with a form.
 * Whenever a user fills an input field, the corresponding text inside the LabeledText component gets focused.
 */
export const FillableText = React.forwardRef<HTMLElement, FillableTextProps>(
  function FillableText({ className, children, ...props }, ref) {
    return (
      <Base
        as="blockquote"
        ref={ref}
        className={clsx(className, {
          'ds-fillable-text': true,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default FillableText;
