import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import CloseButton from '@digigov/react-core/CloseButton';

export interface FilterHeadingContainerProps extends BaseProps<'div'> {
  /**
   * closeLabel is optional.
   * This declares the label of the close icon.
   * @default 'Κλείσιμο'
   */
  closeLabel?: string;

  /**
   * onClick is optional.
   * This declares the click event of the close icon.
   * @default undefined
   */
  onClick?: (e: React.MouseEvent<HTMLElement, MouseEvent>) => void;
}
/**
 * Use FilterHeadingContainer component inside FilterContainer
 * for filters heading title and close icon(for mobiles).
 * When the Filters are being used inside a Drawer component, you don't have to
 * use the FilterHeadingContainer component
 */
export const FilterHeadingContainer = React.forwardRef<
  HTMLDivElement,
  FilterHeadingContainerProps
>(function FilterHeadingContainer(
  { onClick, closeLabel = 'Κλείσιμο', className, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-filter__heading': true,
      })}
      {...props}
    >
      {children}
      {onClick && (
        <CloseButton
          onClick={(e) => {
            onClick(e);
          }}
        >
          {closeLabel}
        </CloseButton>
      )}
    </Base>
  );
});

export default FilterHeadingContainer;
