import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface FooterListProps extends BaseProps<'ul'> {
  /**
   * columns is optional.
   * The values for this are 1 and 2. The default value is 1.
   * @value 1
   * @value 2
   */
  columns?: 1 | 2;

  /**
   * layout is optional.
   * The default value is vertical. Use horizontal to make a horizontal list.
   * If it is horizontal, it can't have columns.
   */
  layout?: 'horizontal' | 'vertical';
}
/**
 * FooterList is used inside the FooterNavigationSection.
 * This component takes a list of FooterListItem component as its children.
 */
export const FooterList = React.forwardRef<HTMLUListElement, FooterListProps>(
  function FooterList(
    { columns, layout = 'vertical', className, children, ...props },
    ref
  ) {
    return (
      <Base
        as="ul"
        ref={ref}
        className={clsx(className, {
          'ds-footer__list': true,
          'ds-footer__list--columns-2': columns === 2 && layout === 'vertical',
          'ds-footer__list--horizontal': layout === 'horizontal',
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default FooterList;
