import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface HeaderLogoProps extends BaseProps<'a'> {
  /**
  * src is optional.

  */
  src?: string;
  /**
  * href is optional.

  */
  altText?: string;
}
/**
 * Use this component inside the Header to provide a logo.
 */
export const HeaderLogo = React.forwardRef<HTMLAnchorElement, HeaderLogoProps>(
  function HeaderLogo({ href, src, altText, className, ...props }, ref) {
    return (
      <Base
        as="a"
        href={href}
        ref={ref}
        className={clsx(className, {
          'ds-header__link': true,
        })}
        {...props}
      >
        <img
          src={src}
          className={clsx(className, {
            'ds-header__logo': true,
          })}
          alt={altText}
        />
      </Base>
    );
  }
);
export default HeaderLogo;
