import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface HeaderNavMenuContentProps extends BaseProps<'div'> {}
/**
 *  Use HeaderMenuContent inside HeaderSection as a wrapper for the header items(eg HeaderTitle, HeaderLog,
 *  NavHorizontaList, SVG-icons  etc).
 *  HeaderMenuContent must only used when we use NavHorizontaList menu.
 */
export const HeaderNavMenuContent = React.forwardRef<
  HTMLDivElement,
  HeaderNavMenuContentProps
>(function HeaderNavMenuContent({ className, children, ...props }, ref) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-header-nav-menu__content': true,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default HeaderNavMenuContent;
