import React from 'react';
import clsx from 'clsx';
import Typography, { TypographyProps } from '@digigov/react-core/Typography';

export interface HeadingCaptionProps extends TypographyProps {
  /**
   * size is optional. The default value is 'lg'.
   * This size should be the same as the matching Heading.
   * @value 'xl'
   * @value 'lg'
   * @value 'md'
   * @default 'lg'
   */
  size?: 'xl' | 'lg' | 'md';
}
/**
 * Sometimes you may need to make it clear that a page is part of a larger section or group.
 * To do this, you can use a Heading with a HeadingCaption above it.
 */
export const HeadingCaption = React.forwardRef<
  HTMLSpanElement,
  HeadingCaptionProps
>(function HeadingCaption({ size = 'lg', className, children, ...props }, ref) {
  return (
    <Typography
      as="span"
      ref={ref}
      className={clsx(className, {
        [`ds-caption-${size}`]: size !== undefined,
      })}
      {...props}
    >
      {children}
    </Typography>
  );
});

export default HeadingCaption;
