import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import logoEl from '@digigov/react-core/HellenicRepublicLogo/logo-el';
import logoEn from '@digigov/react-core/HellenicRepublicLogo/logo-en';
import logoElInverted from '@digigov/react-core/HellenicRepublicLogo/logo-inverted-el';
import logoEnInverted from '@digigov/react-core/HellenicRepublicLogo/logo-inverted-en';

export interface HellenicRepublicLogoProps extends BaseProps<'img'> {
  /**
   * lang is optional.
   * Use this to define the language version of the logo. Default is el.
   * @value 'el'
   * @value 'en'
   */
  lang?: 'el' | 'en';
}
/**
 * HellenicRepublicLogo is used mainly at the Footer.
 * This component can't have children.
 */
export const HellenicRepublicLogo = React.forwardRef<
  HTMLImageElement,
  HellenicRepublicLogoProps
>(function HellenicRepublicLogo({ lang, className, children, ...props }, ref) {
  const logo = lang === 'en' ? logoEn : logoEl;
  const logoInverted = lang === 'en' ? logoEnInverted : logoElInverted;
  return (
    <>
      <Base
        as="img"
        src={logo}
        ref={ref}
        className={clsx(className, {
          'ds-footer__government-logo': true,
        })}
        {...props}
        alt="Hellenic Republic Logo"
      >
        {children}
      </Base>
      <Base
        as="img"
        src={logoInverted}
        ref={ref}
        className={clsx(className, {
          'ds-footer__government-logo-inverted': true,
        })}
        {...props}
        alt="Hellenic Republic Logo"
      >
        {children}
      </Base>
    </>
  );
});

export default HellenicRepublicLogo;
