import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface ImageLogoProps extends BaseProps<'img'> {
  /**
   * src is optional.
   * src is used to display images.
   */
  src?: string;
  /**
   * variant is optional.
   * variant is used to display images depending the theme (dark, light).
   */
  variant?: 'light' | 'dark';
}
/**
 * ImageLogo is used as a generic component for digigov images.
 * This component can't have children.
 */
export const ImageLogo = React.forwardRef<HTMLImageElement, ImageLogoProps>(
  function ImageLogo({ src, variant, className, ...props }, ref) {
    return (
      <>
        <Base
          as="img"
          src={src}
          ref={ref}
          printHidden
          className={clsx(className, {
            'ds-image-logo': variant === undefined,
            [`ds-image-logo-${variant}`]: variant !== undefined,
          })}
          {...props}
        />
      </>
    );
  }
);

export default ImageLogo;
