import React from 'react';
import { BaseProps } from '@digigov/react-core/Base';
import ImageLogo from '@digigov/react-core/ImageLogo';

export interface ImageLogoSet extends BaseProps<'img'> {
  /**
   * src is optional.
   * src is used to display images.
   */
  src?: string;
  /**
   * variant is optional.
   * variant is used to display images depending the theme (dark, light).
   */
  variants?: ('dark' | 'light')[];
}
/**
 * ImageLogoSet is used as image inverter depending the theme (dark, light).
 * This component can't have children.
 */
export const ImageLogoSet = React.forwardRef<HTMLImageElement, ImageLogoSet>(
  function ImageLogoSet({ src, variants = ['dark', 'light'], ...props }, ref) {
    return (
      <>
        {variants.map((variant) => {
          const imageSrc = src?.replace(/(\.[^.]+)$/, `--${variant}$1`);
          return (
            <ImageLogo
              key={variant}
              ref={ref}
              variant={variant}
              src={imageSrc}
              {...props}
            />
          );
        })}
      </>
    );
  }
);

export default ImageLogoSet;
