import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface LabelFieldProps extends BaseProps<'span'> {
  /**
   * size is optional. The default value is 'lg'
   * @value 'xl'
   * @value 'lg'
   * @value 'md'
   * @value 'sm'
   */
  size?: 'xl' | 'lg' | 'md' | 'sm';
  /**
   * heading is optional.
   * Add this prop if this Field component is the only one in this page.
   * The default value is false.
   * @value true
   * @value false
   * @default false
   */
  heading?: boolean;
}
/**
 * Label component defines a label for several elements at forms.
 */
export const LabelTitle = React.forwardRef<HTMLSpanElement, LabelFieldProps>(
  function LabelTitle(
    { size, className, heading = false, children, ...props },
    ref
  ) {
    return (
      <Base
        as="span"
        ref={ref}
        className={clsx(className, {
          'ds-label__title': true,
          [`ds-label__title--${size}`]: size !== undefined,
        })}
        {...(heading && { role: 'heading', 'aria-level': 1 })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default LabelTitle;
