import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface LabeledTextProps extends BaseProps<'span'> {
  /**
   * Set active true when the label is focused. Default value is false.
   * If the active property is being set to true the background color is yellow otherwise it's light grey.
   * @value true
   * @value false
   */
  active?: boolean;
}
/**
 * LabeledText can be used to add style to some text.
 * More specifically it adds background color and changes the font weight to bold.
 * LabeledText is used inside Fillabletext component.
 */
export const LabeledText = React.forwardRef<HTMLSpanElement, LabeledTextProps>(
  function LabeledText({ className, children, active, ...props }, ref) {
    return (
      <Base
        as="span"
        ref={ref}
        className={clsx(className, {
          'ds-labeled-text': true,
          'ds-labeled-text--active': active,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default LabeledText;
