import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface LayoutProps extends BaseProps<'div'> {
  /**
   * @value true
   * @value false
   * @default true
   */
  fullHeight?: boolean;
}
/**
 * Wrapper component for the entire page except the Header and the Footer.
 */
export const Layout = React.forwardRef<HTMLDivElement, LayoutProps>(
  function Layout({ className, children, fullHeight = true, ...props }, ref) {
    return (
      <Base
        as="div"
        ref={ref}
        className={clsx(className, {
          'ds-layout': true,
          'ds-layout--full-height': fullHeight,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Layout;
