import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface LinkBaseProps extends BaseProps<'a'> {
  /**
   * underline is optional. The default value is 'true'.
   * Make it 'false' only if the context tells the user that the text is a link, even without the underline.
   * @value true
   * @value false
   */
  underline?: boolean;
  /**
   * defaultStyle is optional. The default value is 'true'.
   * Make it 'false' only if you need to use a link with different style, and the default style clashes over with your
   * custom styles. For example, BreadcrumbsListItem is a link but it has a different styling.
   * @value true
   * @value false
   */
  defaultStyle?: boolean;
}
/**
 * This component defines a hyperlink, which is used to link from one page to another.
 */
export const LinkBase = React.forwardRef<HTMLAnchorElement, LinkBaseProps>(
  function LinkBase(
    { underline = true, defaultStyle = true, className, children, ...props },
    ref
  ) {
    return (
      <Base
        as="a"
        ref={ref}
        className={clsx(className, {
          'ds-link': defaultStyle,
          'ds-link--no-underline': !underline,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default LinkBase;
