import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface ListProps extends BaseProps<'ol'> {
  /**
   * listStyle is optional. By default, the list style is none.
   * @value 'bullet'
   * @value 'number'
   * @value 'none'
   * @default 'none'
   */
  listStyle?: 'bullet' | 'number' | 'none';
  /**
   * dense is optional. Use it to add less space between the list items.
   * @value true
   * @value false
   * @default true
   */
  dense?: boolean;
  /**
   * layout is optional.
   * Use it to display the list items horizontally or vertically.
   * @value 'horizontal'
   * @value 'vertical'
   * @default 'vertical'
   */
  layout?: 'horizontal' | 'vertical';
}
/**
 * List component is used for listing items.
 * This component must contain ListItem component.
 */
export const List = React.forwardRef<HTMLOListElement, ListProps>(function List(
  { listStyle = 'none', dense = true, layout, className, children, ...props },
  ref
) {
  return (
    <Base
      as="ol"
      ref={ref}
      className={clsx(className, {
        'ds-list': true,
        'ds-list--bullet': listStyle === 'bullet',
        'ds-list--number': listStyle === 'number',
        'ds-list--spaced': !dense,
        'ds-list--horizontal': layout === 'horizontal',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default List;
