import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface MastheadProps extends BaseProps<'section'> {
  /**
   *
   * color prop changes the background color of MastHead component.
   * default value is primary.
   * @value 'primary'
   * @value 'secondary'
   * @default 'primary'
   */
  color?: 'primary' | 'secondary';
}
/**
 * Use the Masthead on the top of the page.
 */
export const Masthead = React.forwardRef<HTMLDivElement, MastheadProps>(
  function Masthead({ className, children, color = 'primary', ...props }, ref) {
    return (
      <Base
        as="section"
        ref={ref}
        className={clsx(className, {
          'ds-masthead': true,
          'ds-background-dark': color === 'primary',
          'ds-masthead--primary': color === 'primary',
          'ds-masthead--secondary': color === 'secondary',
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Masthead;
