import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface ModalContainerProps extends BaseProps<'div'> {
  /**
   * @value true
   * @value false
   */
  open?: boolean;
  /**
   * dense is optional.
   * @value true ModalContainer and its children will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
  /**
   * gaps is optional.
   * @value false there will be no extra gaps among children components.
   * @value true
   * @default true
   */
  gaps?: boolean;
}
/**
 * Modals can be used to open a pop-up dialog box and provide critical information
 * or ask for a decision. Modals disable all app functionality when they appear, and
 * remain on screen until confirmed, dismissed, or a required action has been taken
 * Use Modal as parent component to wrap ModalHeading, ModalText and ModalAction components
 */
export const ModalContainer = React.forwardRef<
  HTMLDivElement,
  ModalContainerProps
>(function ModalContainer(
  { className, gaps = true, children, open, dense, ...props },
  ref
) {
  return (
    <Base
      ref={ref}
      as="div"
      className={clsx(className, {
        'ds-modal-container': true,
        'ds-modal-container--open': open,
        'ds-modal-container--dense': dense,
      })}
      {...props}
    >
      <Base as="div" className="ds-modal">
        {gaps ? (
          <Base as="div" className="ds-modal__body">
            {children}
          </Base>
        ) : (
          children
        )}
      </Base>
    </Base>
  );
});

export default ModalContainer;
