import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface NavListItemBadgeProps extends BaseProps<'span'> {
  /**
   * text is optional.
   * text prop contains text to be displayed in the badge.
   */
  text?: string;
}
/**
 * NavListItemBadge is used inside NavListItemAction.
 * This component adds a badge to a NavListItem.
 */
export const NavListItemBadge = React.forwardRef<
  HTMLSpanElement | HTMLAnchorElement,
  NavListItemBadgeProps
>(function NavListItemBadge({ text, className, ...props }, ref) {
  return (
    <Base
      as="span"
      ref={ref}
      className={clsx(className, {
        'ds-nav__list-item-badge': true,
      })}
      {...props}
    >
      {text}
    </Base>
  );
});

export default NavListItemBadge;
