import React from 'react';
import clsx from 'clsx';
import { BaseProps } from '@digigov/react-core/Base';
import Link from '@digigov/react-core/LinkBase';

export interface NavListItemLinkProps extends BaseProps<'a'> {
  /**
   * When the NavListItemLink is active, that means that we are in this option / page of the Nav.
   * active is optional.
   *
   * @value true
   * @value false
   */
  active?: boolean;
}
/**
 * NavListItemLink is an <a> element. It should be inside the NavListItem component.
 */
export const NavListItemLink = React.forwardRef<
  HTMLAnchorElement,
  NavListItemLinkProps
>(function NavListItemLink(
  { active, href, className, children, ...props },
  ref
) {
  return (
    <Link
      href={href}
      ref={ref}
      className={clsx(className, {
        'ds-nav__list-item-link': true,
        'ds-nav__list-item-link--active': active,
      })}
      {...props}
    >
      {children}
    </Link>
  );
});

export default NavListItemLink;
