import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface NotificationBannerContainerProps extends BaseProps<'div'> {
  /**
   * variant is optional.
   * variant is used to change the color of the NotificationBannerContainer.
   * @value 'info'
   * @value 'success'
   * @value 'error'
   * @value 'error-group'
   * @default 'info'.
   */
  variant?: 'info' | 'success' | 'error' | 'error-group';
  /**
   * dense is optional.
   * @value true NotificationBannerContainer will be dense.
   * @value false
   * @default false
   * */
  dense?: boolean;
}
/**
 * Details for the NotificationBannerContainer.
 * NotificationBannerContainer component informs users about something they need to know about
 * NotificationBannerContainer component must be placed at the top of the page.
 * NotificationBannerContainer wraps NotificationBannerContainerHeader, NotificationBannerContainerContent,NotificationBannerContainerHeading
 * and NotificationBannerContainerLink components as children
 */
export const NotificationBannerContainer = React.forwardRef<
  HTMLDivElement,
  NotificationBannerContainerProps
>(function NotificationBannerContainer(
  { variant = 'info', className, dense, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      role="region"
      aria-labelledby="ds-notification-banner-title"
      data-module="ds-notification-banner"
      ref={ref}
      className={clsx(className, {
        'ds-notification-banner': true,
        [`ds-notification-banner--${variant}`]: variant !== undefined,
        'ds-notification-banner--dense': dense,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default NotificationBannerContainer;
