import React from 'react';
import clsx from 'clsx';
import Heading, { HeadingProps } from '@digigov/react-core/Heading';

export interface NotificationBannerHeadingProps extends HeadingProps {}
/**
 * Details for the NotificationBannerHeading.
 * NotificationBannerHeading component is used for placing text content to NotificationBanner component.
 * NotificationBannerHeading component must be used inside NotificationBannerContent as children
 */
export const NotificationBannerHeading = React.forwardRef<
  HTMLHeadingElement,
  NotificationBannerHeadingProps
>(function NotificationBannerHeading({ className, children, ...props }, ref) {
  return (
    <Heading
      element="h3"
      size="md"
      ref={ref}
      className={clsx(className, {
        'ds-notification-banner__heading': true,
      })}
      {...props}
    >
      {children}
    </Heading>
  );
});

export default NotificationBannerHeading;
