import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface PaginationListItemProps extends BaseProps<'li'> {
  /**
   * active is optional. Default value is false.
   * @value true
   * @value false
   * @default true
   */
  active?: boolean;
  /**
   * active is optional. Default value is false.
   * @value true
   * @value false
   */
  currentPage?: boolean;
  /**
   * use variant=number for list items that are navigation numbers and variant=dots for the dots item.
   * @value 'number'
   * @value 'dots'
   * @default 'number'
   */
  variant?: 'number' | 'dots';
}
/**
 * PaginationListItem is used inside PaginationList for the items of the pagination list.
 */
export const PaginationListItem = React.forwardRef<
  HTMLLIElement,
  PaginationListItemProps
>(function PaginationListItem(
  {
    active = true,
    currentPage,
    variant = 'number',
    className,
    children,
    ...props
  },
  ref
) {
  return (
    <Base
      as="li"
      ref={ref}
      className={clsx(className, {
        'ds-pagination__item': true,
        'ds-pagination__item--inactive': !active,
        'ds-pagination__item--current': currentPage,
        'ds-pagination__item--dots': variant === 'dots',
      })}
      {...props}
    >
      {variant === 'dots' ? '...' : children}
    </Base>
  );
});

export default PaginationListItem;
