import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface PanelProps extends BaseProps<'div'> {
  /**
   * variant prop is optional.
   * variant prop is used to change the color of the panel.
   * 'success' is the default variant.
   */
  variant?: 'success';
}
/**
 * You should use Panel as the success of the final step of a process.
 */
export const Panel = React.forwardRef<HTMLDivElement, PanelProps>(
  function Panel({ variant = 'success', className, children, ...props }, ref) {
    return (
      <Base
        as="div"
        ref={ref}
        className={clsx(className, {
          'ds-panel': true,
          'ds-panel--success': variant === 'success',
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Panel;
