import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface PhaseBannerProps extends BaseProps<'div'> {
  /**
   * underline is optional.
   * Use this prop when you want to underline the phase banner.
   * @value true
   * @value false
   * @default false
   */
  underline?: boolean;
}
/**
 * PhaseBanner is a component used to show the phase of a service.
 * This component will replace ServiceBadge.
 */
export const PhaseBanner = React.forwardRef<HTMLDivElement, PhaseBannerProps>(
  function PhaseBanner(
    { className, underline = false, children, ...props },
    ref
  ) {
    return (
      <Base
        as="div"
        ref={ref}
        className={clsx(className, {
          'ds-phase-banner': true,
          'ds-phase-banner--underline': underline,
        })}
        {...props}
      >
        <Base
          as="p"
          className={clsx({
            'ds-phase-banner__content': true,
          })}
        >
          {children}
        </Base>
      </Base>
    );
  }
);

export default PhaseBanner;
