import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface RadioContainerProps extends BaseProps<'div'> {
  /**
   * The `layout` prop controls whether the radio items will render next to each other or not.
   * @value 'horizontal'
   * @value 'vertical'
   * @default 'vertical'
   */
  layout?: 'horizontal' | 'vertical';
  /**
   * dense is optional.
   * @value true Radios will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
}
/**
 * RadioContainer component is uses when users can only select one option from a list.
 * It is used as parent component to wrap RadioItem component.
 */
export const RadioContainer = React.forwardRef<
  HTMLDivElement,
  RadioContainerProps
>(function RadioContainer(
  { layout, dense, className, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-radios': true,
        'ds-radios--dense': dense,
        'ds-radios--horizontal': layout === 'horizontal',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default RadioContainer;
