import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface SectionBreakProps extends BaseProps<'hr'> {
  /**
   * visible is optional.
   * By default, SectionBreak only visible by its margin. You can add the 'visible' prop to make it visible with a separator line.
   * @value true
   * @value false
   * @default true
   */
  visible?: boolean;

  /**
   * size is optional and it is about the different size margins.
   * @value 'xl'
   * @value 'lg'
   * @value 'md'
   * @value 'sm'
   * @default 'sm'
   */
  size?: 'xl' | 'lg' | 'md' | 'sm';
}
/**
 * SectionBreak is used to create a thematic break between sections of content.
 */
export const SectionBreak = React.forwardRef<HTMLHRElement, SectionBreakProps>(
  function SectionBreak(
    { visible = true, size = 'sm', className, ...props },
    ref
  ) {
    return (
      <Base
        as="hr"
        ref={ref}
        className={clsx(className, {
          'ds-section-break': true,
          'ds-section-break--visible': visible,
          'ds-section-break--xl': size === 'xl',
          'ds-section-break--lg': size === 'lg',
          'ds-section-break--md': size === 'md',
        })}
        {...props}
      />
    );
  }
);

export default SectionBreak;
