import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface SelectContainerProps extends BaseProps<'select'> {
  /**
   * dense is optional.
   * @value true Select will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
}
/**
 * The SelectContainer component allows users to choose an option from a long list.
 * It is used as a parent component to wrap SelectOption component.
 */
export const SelectContainer = React.forwardRef<
  HTMLSelectElement,
  SelectContainerProps
>(function SelectContainer({ dense, className, children, ...props }, ref) {
  return (
    <Base
      as="select"
      ref={ref}
      className={clsx(className, {
        'ds-select': true,
        'ds-select--dense': dense,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default SelectContainer;
