import React from 'react';
import clsx from 'clsx';
import TextInput, { TextInputProps } from '@digigov/react-core/TextInput';

export interface SingleCharacterInputProps
  extends Omit<TextInputProps, 'maxLength'> {
  /**
  * pattern is optional. The default value is [0-9].
  * Use this prop when you want to give a specific format input.

  * @default '[0-9]*'
  */
  pattern?: string;
}
/**
 * Details for the SingleCharacterInput.
 * SingleCharacterInput component is used for displaying simple digital character inputs.
 * SingleCharacterInput component must be included inside SingleCharacterInputs component as children component
 */
export const SingleCharacterInput = React.forwardRef<
  HTMLInputElement,
  SingleCharacterInputProps
>(function SingleCharacterInput(
  { className, pattern = '[0-9]*', ...props },
  ref
) {
  return (
    <TextInput
      className={clsx({
        className,
        'ds-single-character-input__item': true,
      })}
      inputMode="numeric"
      pattern={pattern}
      ref={ref}
      {...props}
      maxLength={1}
    />
  );
});

export default SingleCharacterInput;
