import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface StepNavAccordionHeadingTextProps extends BaseProps<'span'> {
  /**
   * Use openLabel to display the open state text under the accordion heading text.
   * @default 'Εμφάνιση'
   */
  openLabel?: string;
  /**
   * Use closeLabel to display the close state text under the accordion heading text.
   *
   * @default 'Απόκρυψη'
   */
  closeLabel?: string;
}
/**
 * Use StepNavAccordionHeadingText as title text,
 *
 *
 */
export const StepNavAccordionHeadingText = React.forwardRef<
  HTMLSpanElement,
  StepNavAccordionHeadingTextProps
>(function StepNavAccordionHeadingText(
  {
    className,
    openLabel = 'Εμφάνιση',
    closeLabel = 'Απόκρυψη',
    children,
    ...props
  },
  ref
) {
  return (
    <>
      <Base
        as="span"
        ref={ref}
        className={clsx(className, {
          'ds-step-nav__accordion__heading__text': true,
        })}
        {...props}
      >
        {children}
      </Base>
      <span className="ds-step-nav__accordion__closed">{openLabel}</span>
      <span className="ds-step-nav__accordion__opened">{closeLabel}</span>
    </>
  );
});

export default StepNavAccordionHeadingText;
