import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface SummaryListItemProps extends BaseProps<'div'> {
  /**
   *  border is optional.
   *  By default, SummaryListItem has borders. You can remove borders by using border prop.
   *  By default is true
   ** @value true
   * @value false
   * @default true
   */
  border?: boolean;
}
/**
 * SummaryListItem must be inside SummaryList component. Each SummaryListItem is a row in the SummaryList table.
 * This component must contain SummaryListItemKey, SummaryListItemValue and SummaryListItemAction, in that order.
 */
export const SummaryListItem = React.forwardRef<
  HTMLDivElement,
  SummaryListItemProps
>(function SummaryListItem(
  { className, children, border = true, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-summary-list__row': true,
        'ds-summary-list__row--no-border': !border,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default SummaryListItem;
