import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface SummaryListItemKeyProps extends BaseProps<'dt'> {
  /**
   * sm shows the width of the key column for small screens.
   * @default 3
   */
  sm?: WidthValues;
  /**
   * md shows the width of the key column for medium screens.
   */
  md?: WidthValues;
  /**
   * lg shows the width of the key column for large screens.
   */
  lg?: WidthValues;
}

export type WidthValues = 3 | 4 | 5 | 6 | 7 | 8 | 9;
/**
 * SummaryListItemKey is used within the SummaryListItem component.
 * In this column we place the key information for the row (ex. "Name", "Address", etc).
 */
export const SummaryListItemKey = React.forwardRef<
  HTMLElement,
  SummaryListItemKeyProps
>(function SummaryListItemKey(
  { sm = 3, md, lg, className, children, ...props },
  ref
) {
  return (
    <Base
      as="dt"
      ref={ref}
      className={clsx(className, {
        'ds-summary-list__key': true,
        [`ds-summary-list__key--sm-${sm}`]: sm !== undefined,
        [`ds-summary-list__key--md-${md}`]: md !== undefined,
        [`ds-summary-list__key--lg-${lg}`]: lg !== undefined,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default SummaryListItemKey;
