import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TableCaptionProps extends BaseProps<'caption'> {
  /**
   * size is optional.
   * The props are 'sm' for small, 'md' for medium, 'lg' for large and 'xl' for extra large .
   * Default value is 'md'.
   * @value 'sm'
   * @value 'md'
   * @value 'lg'
   * @value 'xl'
   * @default 'md'
   */
  size?: 'sm' | 'md' | 'lg' | 'xl';
}
/**
 * Table caption is used inside the Table component to provide a caption at the top of the table.
 */
export const TableCaption = React.forwardRef<HTMLElement, TableCaptionProps>(
  function TableCaption({ size = 'md', className, children, ...props }, ref) {
    return (
      <Base
        as="caption"
        ref={ref}
        className={clsx(className, {
          'ds-table__caption': true,
          [`ds-table__caption--${size}`]: size !== undefined,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default TableCaption;
