import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
// import PhaseBannerTag from '@digigov/react-core/PhaseBannerTag';

export interface TableDataCellProps extends BaseProps<'td'> {
  /**
   * dataType is optional.
   * Use numeric value when comparing columns of numbers, align the numbers to the right in table cells
   * Default value is text which aligns texts to the center
   * @value 'text'
   * @value 'numeric'
   * @default 'text'
   */
  dataType?: 'text' | 'numeric';
}
/**
 * Use TableDataCell inside the Table component to fill the data of a cell in a table.
 */
export const TableDataCell = React.forwardRef<
  HTMLTableCellElement,
  TableDataCellProps
>(function TableDataCell(
  { dataType = 'text', className, children, ...props },
  ref
) {
  return (
    <Base
      as="td"
      ref={ref}
      className={clsx(className, {
        'ds-table__cell': true,
        'ds-table__cell--numeric': dataType === 'numeric',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default TableDataCell;
