import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TableHeadCellProps extends BaseProps<'th'> {
  /**
   * dataType is optional.
   * Use numeric value prop when comparing columns of numbers, align the numbers to the right in table cells.
   * Default value is text which aligns texts to the center
   * @value 'text'
   * @value 'numeric'
   * @default 'text'
   */
  dataType?: 'text' | 'numeric';
  /**
   * width is optional.
   * Use width prop to define a custom width in your component.
   * @value '25%';
   * @value '33.3%';
   * @value '50%';
   * @value '66.6%';
   * @value '75%';
   * @value '100%';
   * @value 'full';
   */
  width?: '25%' | '33.3%' | '50%' | '66.6%' | '75%' | '100%' | 'full';
}
/**
 * Use TableHeadCell inside the Table component to provide the header row and/or column of the table.
 */
export const TableHeadCell = React.forwardRef<
  HTMLTableCellElement,
  TableHeadCellProps
>(function TableHeadCell(
  { dataType = 'text', width, className, children, ...props },
  ref
) {
  return (
    <Base
      as="th"
      ref={ref}
      className={clsx(className, {
        'ds-table__header': true,
        'ds-table__header--numeric': dataType === 'numeric',
        'ds-!-width-one-quarter': width === '25%',
        'ds-!-width-one-third': width === '33.3%',
        'ds-!-width-one-half': width === '50%',
        'ds-!-width-two-thirds': width === '66.6%',
        'ds-!-width-three-quarters': width === '75%',
        'ds-!-width-full': width === 'full' || width === '100%',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default TableHeadCell;
