import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TableNoDataRowProps extends BaseProps<'td'> {}
/**
 * Use TableNoDataRow inside the Table component when there is no data to show.
 * you can use colSpan prop attribute to expand the td width
 */
export const TableNoDataRow = React.forwardRef<
  HTMLTableCellElement,
  TableNoDataRowProps
>(function TableNoDataRow({ className, children, ...props }, ref) {
  return (
    <tr className="ds-table__row">
      <Base
        as="td"
        colSpan={100}
        ref={ref}
        className={clsx(className, {
          'ds-table__cell': true,
          'ds-table__cell--no-data': true,
        })}
        {...props}
      >
        {children}
      </Base>
    </tr>
  );
});

export default TableNoDataRow;
