import React from 'react';
import Heading from '@digigov/react-core/Heading';
import Hidden, { HiddenProps } from '@digigov/react-core/Hidden';

export interface TabsHeadingProps extends HiddenProps {
  /**
   * size is optional.
   * The values are 'md' for medium and 'sm' for small.
   * Default value is 'sm'.
   * @value 'md'
   * @value 'sm'
   * @default 'sm'
   */
  size?: 'md' | 'sm';
}
/**
 * TabsHeading should be inside the Tabs component. This heading is hidden on desktop screens, but it is always useful for accessibility.
 */
export const TabsHeading = React.forwardRef<
  HTMLHeadingElement,
  TabsHeadingProps
>(function TabsHeading({ size = 'sm', children, ...props }, ref) {
  return (
    <Hidden ref={ref} {...props} mdUp>
      <Heading size={size}>{children}</Heading>
    </Hidden>
  );
});

export default TabsHeading;
