import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TaskListItemTagProps extends BaseProps<'strong'> {
  /**
   * Set status to change the background color of the TaskListItemTag element.
  @value 'primary'
  @value 'secondary'
  @value 'info'
   */
  color?: 'primary' | 'secondary' | 'info';
}
/**
 * TaskListItemTag is used inside the TaskListItem component and it displays the status of the task (completed, not started yet, etc.)
 */
export const TaskListItemTag = React.forwardRef<
  HTMLElement,
  TaskListItemTagProps
>(function PhaseBannerTag({ color, className, children, ...props }, ref) {
  return (
    <Base
      as="strong"
      ref={ref}
      className={clsx(className, {
        'ds-task-list__content__tag': true,
        [`ds-task-list__content__tag--${color}`]: color !== undefined,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default TaskListItemTag;
