import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TimelineProps extends BaseProps<'ol'> {
  /**
   * dense is optional.
   * @value true Timeline will be dense.
   * @value false
   * @default true
   */
  dense?: boolean;
}
/**
 * Timeline component is used for listing items.
 * This component must contain TimelineItem component.
 */
export const Timeline = React.forwardRef<HTMLOListElement, TimelineProps>(
  function Timeline({ dense, className, children, ...props }, ref) {
    return (
      <Base
        as="ol"
        ref={ref}
        className={clsx(className, {
          'ds-timeline': true,
          'ds-timeline--dense': dense,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Timeline;
