import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TimelineHeadingProps extends BaseProps<'h2'> {
  /**
   * size is optional. 'lg' is the default value.
   * @value 'lg'
   * @value 'md'
   * @value 'sm'
   * @default 'lg'
   */
  size?: 'lg' | 'md' | 'sm';
  /**
   * element is optional. 'h2' is the default value.
   * @value 'h2'
   * @value 'h3'
   * @value 'h4'
   */
  element?: 'h2' | 'h3' | 'h4';
}

const getComponentBySize = (
  size: TimelineHeadingProps['size']
): TimelineHeadingProps['element'] => {
  switch (size) {
    case 'lg':
      return 'h2';
    case 'md':
      return 'h3';
    case 'sm':
      return 'h4';
    default:
      return 'h2';
  }
};

/**
 * TimelineHeading component is used to place a title in a Timeline component.
 * TimelineHeading component must be wraped inside Timeline component.
 */
export const TimelineHeading = React.forwardRef<
  HTMLHeadingElement,
  TimelineHeadingProps
>(function TimelineHeading(
  { size = 'lg', element, className, children, ...props },
  ref
) {
  const Component = element ? element : getComponentBySize(size);
  return (
    <Base
      as={Component}
      ref={ref}
      className={clsx(className, {
        'ds-timeline__heading': true,
        'ds-timeline__heading-md': size === 'md',
        'ds-timeline__heading-sm': size === 'sm',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default TimelineHeading;
