import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TypographyProps
  extends BaseProps<'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'span' | 'p' | 'code'> {
  /**
   * fontSize is optional.
   * Add this fontSize override prop in order to change the font size.
   * @value 14
   * @value 16
   * @value 19
   * @value 24
   * @value 30
   * @value 36
   * @value 48
   * @value 72
   */
  fontSize?: 14 | 16 | 19 | 24 | 30 | 36 | 48 | 72;
  /**
   * fontWeight is optional.
   * You can add a fontWeight override prop to change the font weight to regular or bold.
   * @value 'regular'
   * @value 'bold'
   */
  fontWeight?: 'regular' | 'bold';
}
/**
 * Typography component is used as generic component for typography.
 * Use Typography component to extend components such as Heading, NormalText Paragraph etc.
 */
export const Typography = React.forwardRef<HTMLHeadingElement, TypographyProps>(
  function Typography(
    { as, fontSize, fontWeight, className, children, ...props },
    ref
  ) {
    return (
      <Base
        as={as}
        ref={ref}
        className={clsx(className, {
          [`ds-!-font-size-${fontSize}`]: fontSize !== undefined,
          [`ds-!-font-weight-${fontWeight}`]: fontWeight !== undefined,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Typography;
