import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface AccordionProps extends BaseProps<'div'> {
  /*
   * horizontalBorders is optional.
   * If 'none', Accordion will have no borders.
   * If 'top', Accordion will have a border on top.
   * If 'bottom', Accordion will have a border on bottom.
   * @value none
   * @value top
   * @value bottom
   * @default top
   */
  horizontalBorders?: 'none' | 'top' | 'bottom';
  /**
   * summaryColor is optional.
   * 'primary' color gives AccordionSectionSummary the default color.
   * 'secondary' color gives AccordionSectionSummary a gray background.
   * @value primary
   * @value secondary
   * @default primary
   * */
  summaryColor?: 'primary' | 'secondary';
  /**
   * dense is optional.
   * If true, AccordionSection will have a smaller padding.
   * @value true
   * @value false
   * @default false
   * */
  dense?: boolean;
}
/**
 * Accordion is the main component for an accordion.
 * Inside this component must be a list of AccordionSection components.
 */
export const Accordion = React.forwardRef<HTMLDivElement, AccordionProps>(
  function Accordion(
    {
      className,
      horizontalBorders = 'top',
      summaryColor = 'primary',
      dense,
      children,
      ...props
    },
    ref
  ) {
    return (
      <Base
        as="div"
        ref={ref}
        className={clsx(className, {
          'ds-accordion': true,
          'ds-accordion--no-border': horizontalBorders === 'none',
          'ds-accordion--border-top': horizontalBorders === 'top',
          'ds-accordion--border-bottom': horizontalBorders === 'bottom',
          'ds-accordion--dense': dense,
          'ds-accordion--secondary': summaryColor === 'secondary',
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Accordion;
