import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface AutoCompleteResultListItemProps extends BaseProps<'li'> {
  /**
  * index is optional.
  * Use index prop to add or not option-odd css class.
  *
  *

  */
  index?: number;
  /**
   * isFocused is optional.
   * Use isFocused prop to focus selected element.
   *
   *
   * @value undefined
   * @value undefined
   */
  isFocused?: boolean | null;
  /**
   * isHovered is optional.
   * Use isHovered prop to hover over elements.
   *
   *
   * @value undefined
   * @value undefined
   */
  isHovered?: boolean | null;
  /**
   * empty is optional.
   * Use empty prop when there are no results in AutoComplete.
   * by default is false.
   *
   * @value true
   * @value false
   * @default false
   */
  empty?: boolean;
}

/**
 * AutoCompleteResultListItem must be inside AutoCompleteResultList compoenent.
 * Use AutoCompleteResultListItem component to list all the values.
 *
 * */
export const AutoCompleteResultListItem = React.forwardRef<
  HTMLLIElement,
  AutoCompleteResultListItemProps
>(function AutoCompleteResultListItem(
  { className, isFocused, isHovered, empty = false, index, children, ...props },
  ref
) {
  return (
    <Base
      as="li"
      ref={ref}
      tabIndex={-1}
      className={clsx(className, {
        'ds-autocomplete__option': true,
        'ds-autocomplete__option--odd': index && index % 2 === 1 ? true : false,
        'ds-autocomplete__option--focused': isFocused && isHovered === null,
        'ds-autocomplete__option--empty': empty,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default AutoCompleteResultListItem;
