import React from 'react';
import clsx from 'clsx';
import { Base, BaseProps } from '@digigov/react-core/Base';

export interface BackToTopContainerProps extends BaseProps<'div'> {
  /**
   * persistent is optional.
   * If true, the BackToTopLink will be visible even the user scrolls down.
   * @value true
   * @value false
   * @default false
   */
  persistent?: boolean;
}

/**
 * BackToTopContainer is a container for the BackToTopLink component and controls its visibility.
 */
export const BackToTopContainer = React.forwardRef<
  HTMLDivElement,
  BackToTopContainerProps
>(function BackToTopContainer(
  { className, persistent, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-back-to-top': true,
        'ds-back-to-top--persistent': persistent,
      })}
      {...props}
    >
      <div
        className={clsx({
          'ds-back-to-top-content': true,
        })}
      >
        {children}
      </div>
    </Base>
  );
});

export default BackToTopContainer;
