import React, {
  DetailedHTMLProps,
  InputHTMLAttributes,
  LegacyRef,
} from 'react';
import { TouchableOpacity, View } from 'react-native';

export type RadioInputProps = Omit<
  DetailedHTMLProps<InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>,
  'ref'
>;

export const RadioInput = React.forwardRef<HTMLInputElement, RadioInputProps>(
  function RadioInput({ value, checked, onChange, ...props }, ref) {
    const handlePress = () => {
      if (onChange) {
        const syntheticEvent = {
          target: {
            value: value,
            checked: true,
          },
        } as React.ChangeEvent<HTMLInputElement>;
        onChange(syntheticEvent);
      }
    };

    return (
      <TouchableOpacity
        ref={ref as LegacyRef<typeof TouchableOpacity>}
        onPress={handlePress}
        {...(props as any)}
      >
        {checked && <View className="ds-radios__input--checked" />}
      </TouchableOpacity>
    );
  }
);

export default RadioInput;
