import React from 'react';
import { Link } from 'expo-router';
import { cssInterop } from 'nativewind';
import { Image, View } from 'react-native';
import Svg, { Path, Circle, Rect, G, Polygon } from 'react-native-svg';
import { Button } from '@digigov/react-core/Base/compat/button.native';
import CompatDetails from '@digigov/react-core/Base/compat/details.native';
import BaseInput from '@digigov/react-core/Base/compat/Input/index.native';
import { Ol } from '@digigov/react-core/Base/compat/ol.native';
export type MapProps<T extends keyof JSX.IntrinsicElements> =
  React.ComponentPropsWithoutRef<T>;

// TODO: use MapProps<K> instead of any for props type
export type MappingType = {
  [K in keyof JSX.IntrinsicElements]?: (
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    props: any
  ) => JSX.Element | React.ReactNode;
};

export const mapping: MappingType = {
  a: ({ children, ...props }) => (
    <Link {...props} asChild>
      <View>{children}</View>
    </Link>
  ),
  img: (props) => <Image {...props} />,
  button: Button,
  input: BaseInput,
  textarea: BaseInput,
  details: CompatDetails,
  ol: Ol,
  path: (props) => <Path {...props} />,
  // @ts-ignore
  svg: cssInterop(Svg, {
    className: {
      target: 'style',
      nativeStyleToProp: { width: true, height: true },
    },
  }),
  rect: (props) => <Rect {...props} />,
  circle: (props) => <Circle {...props} />,
  g: (props) => <G {...props} />,
  polygon: (props) => <Polygon {...props} />,
};
