import clsx from 'clsx';

// Helper function to handle both SpacingValues and SpacingMediaValues
const generateSpacingClasses = (prefix, spacing) => {
  if (typeof spacing === 'object') {
    // It's a SpacingMediaValues (media-specific)
    return {
      [`${prefix}-xs-${spacing?.xs}`]: spacing?.xs !== undefined,
      [`${prefix}-sm-${spacing?.sm}`]: spacing?.sm !== undefined,
      [`${prefix}-md-${spacing?.md}`]: spacing?.md !== undefined,
      [`${prefix}-lg-${spacing?.lg}`]: spacing?.lg !== undefined,
      [`${prefix}-xl-${spacing?.xl}`]: spacing?.xl !== undefined,
    };
  } else if (spacing !== undefined) {
    // It's a regular SpacingValues
    return {
      [`${prefix}-${spacing}`]: true,
    };
  }
  return {};
};

export const basePropGenerator = ({
  display,
  margin,
  marginTop,
  marginBottom,
  marginLeft,
  marginRight,
  m,
  mt,
  mb,
  ml,
  mr,
  mx,
  my,
  padding,
  paddingTop,
  paddingBottom,
  paddingLeft,
  paddingRight,
  p,
  pt,
  pb,
  pr,
  pl,
  px,
  py,
  printHidden,
  printVisible,
  hidden,
  xsUpHidden,
  smUpHidden,
  mdUpHidden,
  lgUpHidden,
  xlUpHidden,
  xsHidden,
  smHidden,
  mdHidden,
  lgHidden,
  xlHidden,
}) => {
  return clsx({
    [`ds-display-${display}`]: display !== undefined,
    ...generateSpacingClasses('ds-m', m ?? margin),
    ...generateSpacingClasses('ds-mt', mt ?? marginTop),
    ...generateSpacingClasses('ds-mb', mb ?? marginBottom),
    ...generateSpacingClasses('ds-mr', mr ?? marginRight),
    ...generateSpacingClasses('ds-ml', ml ?? marginLeft),
    ...generateSpacingClasses('ds-mx', mx),
    ...generateSpacingClasses('ds-my', my),
    ...generateSpacingClasses('ds-p', p ?? padding),
    ...generateSpacingClasses('ds-pt', pt ?? paddingTop),
    ...generateSpacingClasses('ds-pb', pb ?? paddingBottom),
    ...generateSpacingClasses('ds-pr', pr ?? paddingRight),
    ...generateSpacingClasses('ds-pl', pl ?? paddingLeft),
    ...generateSpacingClasses('ds-px', px),
    ...generateSpacingClasses('ds-py', py),
    'ds-print-hidden': !!printHidden,
    'ds-print-visible-block': printVisible === 'block',
    'ds-print-visible-inline': printVisible === 'inline',
    'ds-hidden': !!hidden,
    'ds-hidden-xs-up': !!xsUpHidden,
    'ds-hidden-sm-up': !!smUpHidden,
    'ds-hidden-md-up': !!mdUpHidden,
    'ds-hidden-lg-up': !!lgUpHidden,
    'ds-hidden-xl-up': !!xlUpHidden,
    'ds-hidden-xs': !!xsHidden,
    'ds-hidden-sm': !!smHidden,
    'ds-hidden-md': !!mdHidden,
    'ds-hidden-lg': !!lgHidden,
    'ds-hidden-xl': !!xlHidden,
  });
};
