import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import CheckboxItemInput from '@digigov/react-core/CheckboxItemInput';
import ChoiceDividerText from '@digigov/react-core/ChoiceDividerText';
import LabelContainer from '@digigov/react-core/LabelContainer';

export interface CheckboxItemProps extends BaseProps<'input'> {
  /**
   * dividerText is optional.
   * Add this prop to add a choice divider on top of a checkbox item.
   * The string is the text that it will appear above this checkbox item.
   */
  dividerText?: string;
}
/**
 * Details for the CheckboxItem.
 * CheckboxItem component allows the user to select one or more checkboxes
 * CheckboxItem must be used inside Checkbox component
 */
export const CheckboxItem = React.forwardRef<
  HTMLInputElement,
  CheckboxItemProps
>(function CheckboxItem(
  { name, value, dividerText, className, disabled, children, ...props },
  ref
) {
  return (
    <>
      {dividerText && <ChoiceDividerText>{dividerText}</ChoiceDividerText>}
      <Base
        as="div"
        className={clsx(className, {
          'ds-checkboxes__item': true,
        })}
      >
        <LabelContainer
          className={clsx({
            'ds-checkboxes__label': true,
            'ds-checkboxes__label--disabled': disabled,
          })}
        >
          {children}
          <CheckboxItemInput
            ref={ref}
            name={name}
            value={value}
            disabled={disabled}
            {...props}
          />
        </LabelContainer>
      </Base>
    </>
  );
});

export default CheckboxItem;
