import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface ChipSectionProps extends BaseProps<'ul'> {
  /**
   * @value true
   * @value false
   */
  horizontal?: boolean;
}
/**
 * ChipContainer is used inside Chip component as a container for its items.
 */
export const ChipContainer = React.forwardRef<
  HTMLUListElement,
  ChipSectionProps
>(function ChipContainer({ className, horizontal, children, ...props }, ref) {
  return (
    <Base
      as="ul"
      ref={ref}
      className={clsx(className, {
        'ds-chips': true,
        'ds-chips--horizontal': horizontal,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default ChipContainer;
