import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface ChoiceDividerTextProps extends BaseProps<'div'> {}
/**
 * ChoiceDivider component adds a text divider on top of a Radio or Checkbox item.
 * It's been used as a prop ("divider") inside RadioItem and CheckboxItem.
 */
export const ChoiceDividerText = React.forwardRef<
  HTMLDivElement,
  ChoiceDividerTextProps
>(function ChoiceDividerText({ className, children, ...props }, ref) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-choice-divider-text': true,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default ChoiceDividerText;
