import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface CircularProgressProps extends BaseProps<'svg'> {
  /**
   * color prop is optional.
   * color prop is used to change the color of the loader.
   * @value 'primary' is the default color.
   * @value 'secondary' recommended for dark backgrounds.
   * @default 'primary'
   */
  color?: 'primary' | 'secondary';
  /**
   * size prop is optional.
   * size prop is used to change the size of the loader.
   * @value 'sm'
   * @value 'md'
   * @value 'lg'
   * @default 'md'
   */
  size?: 'sm' | 'md' | 'lg';
}
/**
 * Use CircularProgress component as an animated loader.
 *  CircularProgress can be used inside LoaderContainer component.
 */
export const CircularProgress = React.forwardRef<
  SVGSVGElement,
  CircularProgressProps
>(function CircularProgress(
  { color = 'primary', size = 'md', className, ...props },
  ref
) {
  return (
    <Base
      as="svg"
      ref={ref}
      className={clsx(className, {
        'ds-circular-progress': true,
        'ds-circular-progress--secondary': color === 'secondary',
        'ds-circular-progress--sm': size === 'sm',
        'ds-circular-progress--md': size === 'md',
        'ds-circular-progress--lg': size === 'lg',
      })}
      focusable="false"
      viewBox="0 0 200 200"
      aria-hidden="true"
      {...props}
    >
      <path
        className="ds-circular-progress__circle ds-circular-progress__circle--1"
        d="M26,99.551C26,55.478,60.246,27.5,99.85,27.5S174,55.478,174,99.551,139.455,172.5,99.85,172.5C60.273,172.473,26,143.6,26,99.551Z"
      />
      <path
        className="ds-circular-progress__circle ds-circular-progress__circle--2"
        d="M26,99.551C26,55.478,60.246,27.5,99.85,27.5S174,55.478,174,99.551,139.455,172.5,99.85,172.5C60.273,172.473,26,143.6,26,99.551Z"
      />
    </Base>
  );
});

export default CircularProgress;
