import React from 'react';
import clsx from 'clsx';
import Button, { ButtonProps } from '@digigov/react-core/Button';
import { CloseIcon } from '@digigov/react-icons/CloseIcon';

export interface CloseButtonProps extends ButtonProps {
  /**
   * label is optional.
   * If empty, the CloseButton will only have a close icon.
   * Use this prop to add text beside the close icon. For example: 'Κλείσιμο'.
   */
  label?: string;
}
/**
 * CloseButton is an <button> element. It can be used be inside the FilterSection component.
 */
export const CloseButton = React.forwardRef<
  HTMLButtonElement,
  CloseButtonProps
>(function CloseButton({ label, className, children, ...props }, ref) {
  return (
    <Button
      variant="link"
      className={clsx(className, {
        'ds-close-btn': true,
      })}
      ref={ref}
      {...props}
    >
      {label || children}
      <CloseIcon />
    </Button>
  );
});

export default CloseButton;
