import React from 'react';
import clsx from 'clsx';
import Grid, { GridProps } from '@digigov/react-core/Grid';

export interface ContainerProps extends GridProps {
  /**
   * grid is optional. Set to false if you don't need grid layout.
   * @value true
   * @value false
   * @default true
   */
  grid?: boolean;
  /**
   * fullWidth is optional. Set to true if you need a full width layout.
   * @value true
   * @value false
   * @default false
   */
  fullWidth?: boolean;
}
/**
 * Use Container as a wrapper.
 */
export const Container = React.forwardRef<HTMLDivElement, ContainerProps>(
  function Container(
    { grid = true, fullWidth = false, className, children, ...props },
    ref
  ) {
    return (
      <Grid
        container={grid}
        spacing={grid ? { sm: 12 } : undefined}
        ref={ref}
        className={clsx(className, {
          'ds-container': true,
          'ds-container--full-width': fullWidth,
        })}
        {...props}
      >
        {children}
      </Grid>
    );
  }
);

export default Container;
