import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface CopyToClipboardContainerProps extends BaseProps<'div'> {
  /**
   * @value 'tooltip' is used when you want to show the message inside a tooltip.
   * @value 'banner' is used when you want to show the message inside a banner.
   * @default 'tooltip'
   */
  variant?: 'tooltip' | 'banner';
  /**
   * tooltipAlign is optional.
   * tooltipAlign prop adds tooltip right or left and is used only if variant is tooltip.
   * @value 'right'
   * @value 'left'
   * @default 'right'
   */
  tooltipAlign?: 'right' | 'left';
  /**
   * dense is optional.
   * affects only the density of the tooltip.
   * @value true tooltip will be dense.
   * @value false
   * @default false
   * */
  dense?: boolean;
}
/**
 * CopyToClipboardContainer is a wrapper component for CopyToClipboardMessage
 */
export const CopyToClipboardContainer = React.forwardRef<
  HTMLDivElement,
  CopyToClipboardContainerProps
>(function CopyToClipboardContainer(
  {
    variant = 'tooltip',
    tooltipAlign = 'right',
    className,
    dense,
    children,
    ...props
  },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      {...props}
      className={clsx(className, {
        'ds-copy-to-clipboard': true,
      })}
      {...props}
    >
      <Base
        as="div"
        className={clsx(className, {
          'ds-copy-to-clipboard__tooltip': variant === 'tooltip',
          'ds-copy-to-clipboard__tooltip--dense':
            variant === 'tooltip' && dense,
          'ds-copy-to-clipboard__tooltip--left':
            variant === 'tooltip' && tooltipAlign === 'left',
          'ds-copy-to-clipboard__tooltip--right':
            variant === 'tooltip' && tooltipAlign === 'right',
          'ds-copy-to-clipboard__banner': variant === 'banner',
        })}
      >
        {children}
      </Base>
    </Base>
  );
});

export default CopyToClipboardContainer;
