import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface DateInputContainerProps extends BaseProps<'div'> {
  /**
   * dense is optional.
   * @value true DateInputs will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
}
/**
 * Details for the DateInputContainer.
 * DateInputContainer component is used for helping users enter a memorable date or one they can easily look up
 * It is used as a parent component to wrap DateInputItem component
 *
 */
export const DateInputContainer = React.forwardRef<
  HTMLDivElement,
  DateInputContainerProps
>(function DateInputContainer({ dense, className, children, ...props }, ref) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-date-input': true,
        'ds-date-input--dense': dense,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default DateInputContainer;
