import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import { TextInput } from '@digigov/react-core/TextInput';

export interface DateInputItemProps extends BaseProps<'input'> {
  /**
   * Width property is optional.
   * Use this property for year field to grow width.
   * @value 2
   * @value 4
   * @default 2
   */
  width?: 2 | 4;
  /**
   * error is optional. The default value is false.
   * Use this prop when there is an error at the input.
   * @value true
   * @value false
   */
  error?: boolean;
}
/**
 * Details for the DateInputItem.
 * DateInputItem component is used for displaying date.
 * DateInputItem component must be included inside DateInput component as children component
 */
export const DateInputItem = React.forwardRef<
  HTMLInputElement,
  DateInputItemProps
>(function DateInputItem(
  { name, width = 2, error, className, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      className={clsx(className, {
        'ds-date-input__item': true,
      })}
    >
      <Base
        as="label"
        className={clsx({
          'ds-label': true,
        })}
      >
        {children}
        <TextInput
          ref={ref}
          type="text"
          name={name}
          maxWidth={`${width}-char`}
          error={error}
          {...props}
        />
      </Base>
    </Base>
  );
});

export default DateInputItem;
