import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface DetailsProps extends BaseProps<'details'> {}
/**
 * Details is used to make a page easier to scan when it contains information that only some users will need.
 * Details component wraps DetailsSummary and DetailsContent as children components
 */
export const Details = React.forwardRef<HTMLDetailsElement, DetailsProps>(
  function Details({ className, children, ...props }, ref) {
    return (
      <Base
        as="details"
        ref={ref}
        className={clsx(className, {
          'ds-details': true,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Details;
