import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface DropdownContentProps extends BaseProps<'div'> {
  /**
   * fullWidth is optional.
   * If true, the dropdown content will be full width.
   * @value true
   * @value false
   * @default true
   */
  fullWidth?: boolean;
  /**
   * scrollable prop is optional.
   * If true, the dropdown content will have limited scrollable height.
   * @value true
   * @value false
   * @default false
   */
  scrollable?: boolean;
}
/**
 * You should use DropdownContent component inside Dropdown component.
 */
export const DropdownContent = React.forwardRef<
  HTMLDivElement,
  DropdownContentProps
>(function DropdownContent(
  { fullWidth = true, scrollable, className, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-dropdown__content': true,
        'ds-dropdown__content--full-width': fullWidth,
        'ds-dropdown__content--scrollable': scrollable,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default DropdownContent;
