import React from 'react';
import clsx from 'clsx';
import Heading, { HeadingProps } from '@digigov/react-core/Heading';

export interface FooterHeadingProps extends Omit<HeadingProps, 'size'> {
  /**
   * size is optional.
   * The values are: 'md' for medium, 'sm' for small.
   * The default value is 'sm'.
   * @value 'md'
   * @value 'sm'
   * @default 'sm'
   */
  size?: 'md' | 'sm';
}
/**
 * FooterHeading is a component used for heading in the footer.
 */
export const FooterHeading = React.forwardRef<
  HTMLHeadingElement,
  FooterHeadingProps
>(function FooterHeading(
  { size = 'sm', element = 'h2', className, children, ...props },
  ref
) {
  return (
    <Heading
      element={element}
      ref={ref}
      size={size}
      className={clsx(className, {
        'ds-footer__heading': true,
      })}
      {...props}
    >
      {children}
    </Heading>
  );
});

export default FooterHeading;
