import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface FormProps extends BaseProps<'form'> {
  /**
   * @value true
   * @value false
   * @default false
   */
  grid?: boolean;
}
/**
 * Use this inside the Content component for additional content
 * that will be shown on the left one third of the page
 */
export const Form = React.forwardRef<HTMLFormElement, FormProps>(function Form(
  { className, children, grid = false, ...props },
  ref
) {
  return (
    <Base
      as="form"
      ref={ref}
      className={clsx(className, {
        'ds-form': true,
        'ds-grid': grid,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default Form;
