import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface HeaderSecondaryLogoProps extends BaseProps<'a'> {
  /**
  * src is needed to provide the url that we get the logo from.

  */
  src: string;
  /**
  * href provides the alternative text for the img tag.

  */
  altText?: string;
}
/**
 * HeaderSecondaryLogo is used inside Header for providing additional logos.
 */
export const HeaderSecondaryLogo = React.forwardRef<
  HTMLAnchorElement,
  HeaderSecondaryLogoProps
>(function HeaderSecondaryLogo(
  { href, src, altText, className, ...props },
  ref
) {
  return (
    <Base
      as="a"
      href={href}
      ref={ref}
      className={clsx(className, {
        'ds-header__link': true,
      })}
      {...props}
    >
      <img
        src={src}
        className={clsx(className, {
          'ds-header__secondary-logo': true,
        })}
        alt={altText}
      />
    </Base>
  );
});

export default HeaderSecondaryLogo;
