import React from 'react';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface HiddenProps extends BaseProps<'div'> {
  /**
   * @value true
   * @value false
   * @default false
   */
  xsUp?: boolean;
  /**
   * @value true
   * @value false
   * @default false
   */
  smUp?: boolean;
  /**
   * @value true
   * @value false
   * @default false
   */
  mdUp?: boolean;
  /**
   * @value true
   * @value false
   * @default false
   */
  lgUp?: boolean;
  /**
   * @value true
   * @value false
   * @default false
   */
  xlUp?: boolean;
  /**
   * @value true
   * @value false
   * @default false
   */
  xs?: boolean;
  /**
   * @value true
   * @value false
   * @default false
   */
  sm?: boolean;
  /**
   * @value true
   * @value false
   * @default false
   */
  md?: boolean;
  /**
   * @value true
   * @value false
   * @default false
   */
  lg?: boolean;
  /**
   * @value true
   * @value false
   * @default false
   */
  xl?: boolean;
}
/**
 * Hidden is used to responsively hide children based on the screen size.
 * Each property refers to a specific screen sizes and applies the "invisible"
 * property at the selected screen size and above.
 */
export const Hidden = React.forwardRef<HTMLDivElement, HiddenProps>(
  function Hidden(
    {
      children,
      xsUp = false,
      smUp,
      mdUp,
      lgUp,
      xlUp,
      xs,
      sm,
      md,
      lg,
      xl,
      ...props
    },
    ref
  ) {
    return (
      <Base
        as="div"
        ref={ref}
        xsUpHidden={xsUp}
        smUpHidden={smUp}
        mdUpHidden={mdUp}
        lgUpHidden={lgUp}
        xlUpHidden={xlUp}
        xsHidden={xs}
        smHidden={sm}
        mdHidden={md}
        lgHidden={lg}
        xlHidden={xl}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Hidden;
