import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface NavListProps extends BaseProps<'ul'> {
  /**
   * active prop sets active background color to the nav list.
   * @value true
   * @value false
   * @default false
   */
  active?: boolean;

  /**
   * layout prop sets the display layout for the nav list
   * @value 'vertical'
   * @value 'horizontal'
   * @default 'horizontal'
   */
  layout?: 'vertical' | 'horizontal';

  /**
   * fullWidth gives to the nav list full width.
   * @value true
   * @value false
   * @default true
   */
  fullWidth?: boolean;
}
/**
 * NavList must be inside the Nav.
 * This component has a list of NavListItem component inside.
 */
export const NavList = React.forwardRef<HTMLUListElement, NavListProps>(
  function NavList(
    {
      className,
      active = false,
      layout = 'horizontal',
      fullWidth,
      children,
      ...props
    },
    ref
  ) {
    return (
      <Base
        as="ul"
        ref={ref}
        className={clsx(className, {
          'ds-nav__list': true,
          'ds-nav__list--active': active,
          'ds-nav__list--horizontal': layout === 'horizontal',
          'ds-nav__list--vertical': layout === 'vertical',
          'ds-nav__list--full-width': fullWidth,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default NavList;
