import React from 'react';
import clsx from 'clsx';
import Button, { ButtonProps } from '@digigov/react-core/Button';
import { ChevronIcon } from '@digigov/react-icons';

export interface NavListItemButtonProps extends ButtonProps {
  /**
   * When the NavListItemButton is active, that means that we are in this option / page of the Nav.
   * NavListItemButton for nav menu.
   * active is optional.
   *
   * @value true
   * @value false
   */
  active?: boolean;
  /**
   * use arrow prop if you want to have arrows in navigation buttons.
   * arrow is optional.
   *
   * @value true
   * @value false
   * @default true
   */
  arrow?: boolean;
}
/**
 * NavListItemButton is an <button> element. It should be inside the NavListItem component.
 */
export const NavListItemButton = React.forwardRef<
  HTMLButtonElement,
  NavListItemButtonProps
>(function NavListItemButton(
  { active, className, arrow = true, children, ...props },
  ref
) {
  return (
    <Button
      variant="link"
      ref={ref}
      aria-selected={active}
      className={clsx(className, {
        'ds-nav__list-item-btn': true,
        'ds-nav__list-item-btn--active': active,
      })}
      {...props}
    >
      {children}
      {arrow && <ChevronIcon direction={active ? 'up' : 'down'} />}
    </Button>
  );
});

export default NavListItemButton;
