import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import Container from '@digigov/react-core/Container';

export interface NavMenuContainerProps extends BaseProps<'div'> {
  /**
   * active is optional.
   * Exactly one NavMenu should be active every time.
   * This declares that this content is active and should depend of the 'selected' NavItem.
   * @value true
   * @value false
   */
  active?: boolean;
  /**
   * layout prop sets the display layout for the nav list.
   * @value 'vertical'
   * @value 'horizontal'
   * @default 'horizontal'
   */
  layout?: 'vertical' | 'horizontal';
}
/**
 * NavMenuContainer is the container menu component.
 * Inside this component must be NavMenuContainerContent component.
 */
export const NavMenuContainer = React.forwardRef<
  HTMLDivElement,
  NavMenuContainerProps
>(function NavMenuContainer(
  { className, active, layout = 'horizontal', children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      aria-hidden={!active}
      className={clsx(className, {
        'ds-nav-menu': true,
        'ds-nav-menu--horizontal': layout === 'horizontal',
        'ds-nav-menu--vertical': layout === 'vertical',
        'ds-nav-menu--hidden': !active,
      })}
    >
      <Container
        grid={layout === 'horizontal'}
        spacing={4}
        ref={ref}
        className={className}
        {...props}
      >
        {children}
      </Container>
    </Base>
  );
});

export default NavMenuContainer;
