import React from 'react';
import clsx from 'clsx';
import Typography, { TypographyProps } from '@digigov/react-core/Typography';
export interface NormalTextProps extends TypographyProps {
  /**
   * size is optional.
   * @value 'lg' Use it when a lg text is an introductory paragraph that you can use at the top of a page to summarize the content.
   * @value 'md' The majority of your body should use the standard 'md' size.
   * @value 'sm' Use it sparingly to make your text font size smaller: 16px on larger screens and 14px on smaller screens.
   * @default 'md'
   */
  size?: 'lg' | 'md' | 'sm';
}
/**
 * NormalText component is used for text formatting.
 * If you need a paragraph, use the Paragraph component instead.
 */
export const NormalText = React.forwardRef<
  HTMLSpanElement | HTMLParagraphElement,
  NormalTextProps
>(function NormalText(
  { size = 'md', fontSize, fontWeight, className, children, ...props },
  ref
) {
  return (
    <Typography
      as="span"
      fontWeight={fontWeight}
      fontSize={fontSize}
      ref={ref}
      className={clsx(className, {
        'ds-body': true,
        'ds-body--lg': size === 'lg',
        'ds-body--sm': size === 'sm',
      })}
      {...props}
    >
      {children}
    </Typography>
  );
});

export default NormalText;
