import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import { WarningTextAssistive } from '@digigov/react-core/WarningTextAssistive';

export interface NotificationBannerContentProps extends BaseProps<'div'> {
  /**
   * assistiveText is optional.
   * Default value is "Προσοχή".
   * assistiveText is used to provide a textual warning for assistive technologies like screen readers.
   */
  assistiveText?: string;
  /**
   * variant is optional.
   * variant is used to display red line on the left side of the component and exclamation mark icon with light red as background.
   * @value 'error'
   * @value 'error-group'
   * @default 'error'.
   */
  /**
   * variant is optional.
   * variant error is used to change the color of the NotificationBannerContainer.
   * variant error-group is used to display red line on the left side of the component and exclamation mark icon with light red as background.
   * @value 'error'
   * @value 'error-group'
   * @default 'error'.
   */
  variant?: 'error' | 'error-group';
}
/**
 * Details for the NotificationBannerContent.
 * NotificationBannerContent component is used as a content for
 * NotificationBannerHeading and NotificationBannerLink components.
 * NotificationBannerContent component must be used inside NotificationBanner component as children.
 */
export const NotificationBannerContent = React.forwardRef<
  HTMLDivElement,
  NotificationBannerContentProps
>(function NotificationBannerContent(
  { className, assistiveText, variant, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-notification-banner__content': variant !== 'error-group',
        'ds-notification-error-group-banner__content':
          variant === 'error-group',
      })}
      {...props}
    >
      {variant === 'error-group' ? (
        <>
          <Base
            as="div"
            className={clsx({
              'ds-notification-banner__icon--error-group': true,
            })}
          >
            !
          </Base>
          <WarningTextAssistive>{assistiveText}</WarningTextAssistive>
          <Base as="div" className="ds-notification-banner__text-error-group">
            {children}
          </Base>
        </>
      ) : (
        <>{children}</>
      )}
    </Base>
  );
});

export default NotificationBannerContent;
