import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import Heading from '@digigov/react-core/Heading';

export interface NotificationBannerHeaderProps extends BaseProps<'div'> {}
/**
 * Details for the NotificationBannerHeader.
 * NotificationBannerHeader component is used for placing head title to NotificationBanner component.
 * NotificationBannerHeader component must be used inside NotificationBanner as children.
 */
export const NotificationBannerHeader = React.forwardRef<
  HTMLDivElement,
  NotificationBannerHeaderProps
>(function NotificationBannerHeader({ className, children, ...props }, ref) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-notification-banner__header': true,
      })}
      {...props}
    >
      <Heading
        element="h2"
        size="sm"
        marginBottom={0}
        className={clsx({
          'ds-notification-banner__title': true,
        })}
      >
        {children}
      </Heading>
    </Base>
  );
});

export default NotificationBannerHeader;
