import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface PaginationProps extends BaseProps<'nav'> {
  /**
   * size is optional.
   * You can add this size override prop in order to change the font size.
   * @value 'sm'
   * @value 'md'
   * @default 'md'
   */
  size?: 'sm' | 'md';
}
/**
 * Use Pagination to let users browse through a long list.
 */
export const Pagination = React.forwardRef<HTMLElement, PaginationProps>(
  function Pagination({ className, size = 'md', children, ...props }, ref) {
    return (
      <Base
        as="nav"
        ref={ref}
        className={clsx(className, {
          'ds-pagination': true,
          'ds-pagination--sm': size === 'sm',
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default Pagination;
