import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import FieldContainer from '@digigov/react-core/FieldContainer';
import LabelContainer from '@digigov/react-core/LabelContainer';

export interface RadioConditionalProps extends BaseProps<'div'> {}
/**
 * RadioConditional asks the user a related question when they select a particular radios,
 * so they only see the question when it’s relevant to them.
 * RadioConditional must be used inside Radio component
 */
export const RadioConditional = React.forwardRef<
  HTMLDivElement,
  RadioConditionalProps
>(function RadioConditional({ className, children, ...props }, ref) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-radios__conditional': true,
      })}
      {...props}
    >
      <FieldContainer>
        <LabelContainer>{children}</LabelContainer>
      </FieldContainer>
    </Base>
  );
});

export default RadioConditional;
