import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import ChoiceDividerText from '@digigov/react-core/ChoiceDividerText';
import LabelContainer from '@digigov/react-core/LabelContainer';

export interface RadioItemProps extends BaseProps<'input'> {
  /**
   * dividerText is optional.
   * Add this prop to add a choice dividerText on top of a radio item.
   * The string is the text that it will appear above this radio item.
   */
  dividerText?: string;
}
/**
 * RadioItem component is used for display radio buttons.
 * RadioItem component must be included inside Radio component, as a children component.
 */
export const RadioItem = React.forwardRef<HTMLInputElement, RadioItemProps>(
  function RadioItem(
    {
      dividerText,
      name,
      value,
      className,
      disabled = false,
      children,
      ...props
    },
    ref
  ) {
    return (
      <>
        {dividerText && <ChoiceDividerText>{dividerText}</ChoiceDividerText>}
        <Base
          as="div"
          className={clsx(className, {
            'ds-radios__item': true,
          })}
        >
          <LabelContainer
            className={clsx({
              'ds-radios__label': true,
              'ds-radios__label--disabled': disabled,
            })}
          >
            {children}
            <Base
              as="input"
              ref={ref}
              type="radio"
              name={name}
              value={value}
              className={clsx({
                'ds-radios__input': true,
              })}
              disabled={disabled}
              {...props}
            />
          </LabelContainer>
        </Base>
      </>
    );
  }
);

export default RadioItem;
