import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface LinkProps extends BaseProps<'a'> {}
/**
 * Use the skip link component to help keyboard-only users skip to the main content on a page.
 */
export const SkipLink = React.forwardRef<HTMLAnchorElement, LinkProps>(
  function SkipLink(
    { className, children, href = '#main-content', ...props },
    ref
  ) {
    return (
      <Base
        as="a"
        tabIndex={0}
        href={href}
        ref={ref}
        className={clsx(className, {
          'ds-skip-link': true,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default SkipLink;
