import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface StepNavProps extends BaseProps<'div'> {
  /**
   * dense is optional.
   * @value true StepNav will be dense.
   * @value false
   * @default false
   * */
  dense?: boolean;
}
/**
 * StepNav contains the content or any other element for step-by-step implementation.
 * Use StepNav as wrapper component.
 */
export const StepNav = React.forwardRef<HTMLDivElement, StepNavProps>(
  function StepNav({ className, dense, children, ...props }, ref) {
    return (
      <Base
        as="div"
        ref={ref}
        className={clsx(className, {
          'ds-step-nav': true,
          'ds-step-nav--dense': dense,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default StepNav;
