import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface StepNavAccordionSummaryHeadingProps extends BaseProps<'h2'> {
  /**
   * size is optional. 'lg' is the default value.
   * @value 'lg'
   * @value 'md'
   * @value 'sm'
   * @default 'lg'
   */
  size?: 'lg' | 'md' | 'sm';
  /**
   * element is optional. 'h2' is the default value.
   * @value 'h2'
   * @value 'h3'
   * @value 'h4'
   */
  element?: 'h2' | 'h3' | 'h4';
}

const getComponentBySize = (
  size: StepNavAccordionSummaryHeadingProps['size']
): StepNavAccordionSummaryHeadingProps['element'] => {
  switch (size) {
    case 'lg':
      return 'h2';
    case 'md':
      return 'h3';
    case 'sm':
      return 'h4';
    default:
      return 'h2';
  }
};

/**
 * StepNavAccordionSummaryHeading component is used as wrapper title in a StepNav component.
 * StepNavAccordionSummaryHeading must include StepNavCircleNumber,StepNavAccordionHeadingTitle,
 * StepNavAccordionHeadingText, StepNavAccordionClosed and StepNavAccordionOpened components.
 *
 */
export const StepNavAccordionSummaryHeading = React.forwardRef<
  HTMLHeadingElement,
  StepNavAccordionSummaryHeadingProps
>(function StepNavAccordionSummaryHeading(
  { size = 'lg', element, className, children, ...props },
  ref
) {
  const Component = element ? element : getComponentBySize(size);
  return (
    <Base
      as={Component}
      ref={ref}
      className={clsx(className, {
        'ds-step-nav__accordion__heading': true,
        'ds-step-nav__accordion__heading--md': size === 'md',
        'ds-step-nav__accordion__heading--sm': size === 'sm',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default StepNavAccordionSummaryHeading;
