import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface StepNavCircleNumberProps extends BaseProps<'span'> {
  /**
   * Use border prop to add or remove border from StepNavCircleNumber component.
   * Default prop border is true.
   *
   * @value true
   * @value false
   * @default true
   */
  border?: boolean;
}

/**
 * StepNavCircleNumber component is used for displaying the number of each step.
 * Use StepNavCircleNumber inside StepNavAccordionSummaryHeading.
 */
export const StepNavCircleNumber = React.forwardRef<
  HTMLSpanElement,
  StepNavCircleNumberProps
>(function StepNavCircleNumber(
  { className, children, border = true, ...props },
  ref
) {
  return (
    <Base
      ref={ref}
      className={clsx(className, {
        'ds-step-nav__circle': true,
        'ds-step-nav__circle--number': true,
        'ds-step-nav__circle--number__no-border': border === false,
      })}
      {...props}
    >
      <span className="ds-step-nav__circle-inner">
        <span className="ds-step-nav__circle-background">{children}</span>
      </span>
    </Base>
  );
});

export default StepNavCircleNumber;
