import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface SummaryListProps extends BaseProps<'dl'> {
  /**
   * border is optional.
   * By default, SummaryList has borders. You can remove borders by using border prop.
   * By default is true
   * @value true
   * @value false
   * @default true
   */
  border?: boolean;
  /**
   * noLastBorder is optional.
   * By default, SummaryList has borders. You can remove last border by using noLastBorder prop.
   * By default is true
   * @value true
   * @value false
   * @default false
   */
  noLastBorder?: boolean;
}
/**
 * SummaryList used as a table with summary information.
 * It must contain a list of SummaryListItem components.
 */
export const SummaryList = React.forwardRef<HTMLDListElement, SummaryListProps>(
  function SummaryList(
    { className, noLastBorder = false, border = true, children, ...props },
    ref
  ) {
    return (
      <Base
        as="dl"
        ref={ref}
        className={clsx(className, {
          'ds-summary-list': true,
          'ds-summary-list--no-border': !border,
          'ds-summary-list--no-last-border': noLastBorder,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default SummaryList;
