import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface SummaryListItemActionProps extends BaseProps<'dd'> {}
/**
 * SummaryListItemAction is used within the SummaryListItem component.
 * In this column we place the action that the user can do, based on the information on the rest of the row.
 */
export const SummaryListItemAction = React.forwardRef<
  HTMLElement,
  SummaryListItemActionProps
>(function SummaryListItemAction({ className, children, ...props }, ref) {
  return (
    <Base
      as="dd"
      ref={ref}
      className={clsx(className, {
        'ds-summary-list__actions': true,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default SummaryListItemAction;
