import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TableBodyProps extends BaseProps<'tbody'> {
  /**
   * verticalAlign is optional. Default value is 'middle'.
   * This prop set the vertical align of the body's content.
   * @value 'middle'
   * @value 'top'
   * @value 'bottom'
   * @default 'middle'
   */
  verticalAlign?: 'middle' | 'top' | 'bottom';
}
/**
 * Use TableBody inside the Table component to provide for the table data.
 */
export const TableBody = React.forwardRef<
  HTMLTableSectionElement,
  TableBodyProps
>(function TableBody(
  { verticalAlign = 'middle', className, children, ...props },
  ref
) {
  return (
    <Base
      as="tbody"
      ref={ref}
      className={clsx(className, {
        'ds-table__body': true,
        'ds-table__body--vertical-top': verticalAlign === 'top',
        'ds-table__body--vertical-bottom': verticalAlign === 'bottom',
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default TableBody;
