import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TableContainerProps extends BaseProps<'div'> {
  /**
   * border is optional. Set to true if you need a border for the Table.
   * @value true
   * @value false
   * @default false
   */
  border?: boolean;
}
/**
 * Use TableContainer as a wrapper for a Table. It is used when the table is wider that the viewport width.
 */
export const TableContainer = React.forwardRef<
  HTMLDivElement,
  TableContainerProps
>(function TableContainer(
  { border = false, className, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-table-container': true,
        'ds-table-container--border': border,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default TableContainer;
