import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TableLoaderBackgroundProps extends BaseProps<'div'> {}
/**
 * Use TableLoaderBackground component in tables in order to add blur and opacity background when data are loading.
 * TableLoaderBackground is the parent component and takes as children the LoaderContainer component.
 */
export const TableLoaderBackground = React.forwardRef<
  HTMLDivElement,
  TableLoaderBackgroundProps
>(function TableLoaderBackground({ children, className, ...props }, ref) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-table__loading': true,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default TableLoaderBackground;
