import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TableRowProps extends BaseProps<'tr'> {
  /**
   * highlight is optional.
   * Add the highlight prop to add a highlight line on the left of the row.
   * @value true
   * @value false
   * @default false
   */
  highlight?: boolean;

  /**
   * color is optional.
   * color doesn't apply if the Table parent component has the prop variant='zebra'.
   * @value 'primary'
   * @value 'secondary'
   * @default 'primary'
   */
  color?: 'primary' | 'secondary';
}
/**
 * Use TableRow inside the Table component to provide a new row to the table.
 */
export const TableRow = React.forwardRef<HTMLTableRowElement, TableRowProps>(
  function TableRow(
    { highlight = false, color, className, children, ...props },
    ref
  ) {
    return (
      <Base
        as="tr"
        ref={ref}
        className={clsx(className, {
          'ds-table__row': true,
          'ds-table__row--highlight': highlight,
          'ds-table__row--secondary': color === 'secondary',
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default TableRow;
