import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TabsProps extends BaseProps<'div'> {
  /**
   * dense is optional.
   * @value true Tabs will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
}
/**
 * Tabs is the main component for tabs.
 * This component must contain TabsHeading, TabsList, and a list of TabsPanel component.
 */
export const Tabs = React.forwardRef<HTMLDivElement, TabsProps>(function Tabs(
  { className, dense, children, ...props },
  ref
) {
  return (
    <Base
      as="div"
      ref={ref}
      className={clsx(className, {
        'ds-tabs': true,
        'ds-tabs--dense': dense,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default Tabs;
