import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TabsListItemBaseProps extends BaseProps<'a'> {
  /**
   * open is optional.
   * Exaclty one TabsListItemBase should be open every time.
   * @value true declares that this tab is open.
   * @value false
   */
  open?: boolean;
}
/**
 * TabsListItemBase should be inside the TabsList.
 * In here we declare the title of the tab.
 */
export const TabsListItemBase = React.forwardRef<
  HTMLAnchorElement,
  TabsListItemBaseProps
>(function TabsListItemBase({ open, className, children, ...props }, ref) {
  return (
    <li
      role="presentation"
      className={clsx(className, {
        'ds-tabs__list-item': true,
        'ds-tabs__list-item-selected': open,
      })}
    >
      <Base
        as="a"
        ref={ref}
        role="tab"
        aria-selected={open}
        className={clsx({
          'ds-tabs__tab': true,
        })}
        {...props}
      >
        {children}
      </Base>
    </li>
  );
});

export default TabsListItemBase;
