import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TabsPanelBaseProps extends BaseProps<'div'> {
  /**
   * active is optional.
   * Exaclty one TabsPanelBase should be active every time.
   * This declares that this content is active and should depend of the 'selected' TabsList.
   * @value true
   * @value false
   */
  active?: boolean;
}
/**
 * TabsPanelBase is inside the Tabs component.
 * Every TabsListItem relates to a TabsPanelBase.
 */
export const TabsPanelBase = React.forwardRef<
  HTMLDivElement,
  TabsPanelBaseProps
>(function TabsPanelBase({ active, className, children, ...props }, ref) {
  return (
    <Base
      as="div"
      ref={ref}
      role="tabpanel"
      aria-hidden={!active}
      className={clsx(className, {
        'ds-tabs__panel': true,
        'ds-tabs__panel--visible': active,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default TabsPanelBase;
