import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TaskListProps extends BaseProps<'ol'> {
  /**
   * dense is optional.
   * @value true TaskList will be dense.
   * @value false
   * @default false
   * */
  dense?: boolean;
}
/**
 * TaskList component is used for listing items.
 * This component must contain TaskListItem component.
 */
export const TaskList = React.forwardRef<HTMLOListElement, TaskListProps>(
  function TaskList({ className, dense, children, ...props }, ref) {
    return (
      <Base
        as="ol"
        ref={ref}
        className={clsx(className, {
          'ds-task-list': true,
          'ds-task-list--dense': dense,
        })}
        {...props}
      >
        {children}
      </Base>
    );
  }
);

export default TaskList;
