import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface TextAreaProps extends BaseProps<'textarea'> {
  /**
   * error is optional. The default value is false.
   * Use this prop when there is an error at the input.
   * @value true
   * @value false
   */
  error?: boolean;
  /**
   * dense is optional.
   * @value true TextArea will be dense.
   * @value false
   * @default false
   */
  dense?: boolean;
}
/**
 * Textarea component is used when you need to let users enter an
 * amount of text that’s longer than a single line.
 */
export const TextArea = React.forwardRef<HTMLTextAreaElement, TextAreaProps>(
  function TextArea({ name, rows, error, dense, className, ...props }, ref) {
    const defaultRows = dense ? 3 : 6;
    return (
      <Base
        as="textarea"
        name={name}
        rows={rows || defaultRows}
        ref={ref}
        className={clsx(className, {
          'ds-textarea': true,
          'ds-textarea--dense': dense,
          'ds-input--error': error,
        })}
        {...props}
      />
    );
  }
);

export default TextArea;
