import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface VisuallyHiddenProps extends BaseProps<'span'> {}
/**
 * Details for the VisuallyHidden.
 * VisuallyHidden component provides text for screen readers that is visually hidden.
 */
export const VisuallyHidden = React.forwardRef<
  HTMLSpanElement,
  VisuallyHiddenProps
>(function VisuallyHidden({ className, children, ...props }, ref) {
  return (
    <Base
      as="span"
      ref={ref}
      className={clsx(className, {
        'ds-visually-hidden': true,
      })}
      {...props}
    >
      {children}
    </Base>
  );
});

export default VisuallyHidden;
