import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';
import { WarningTextAssistive } from '@digigov/react-core/WarningTextAssistive';
export interface WarningTextProps extends BaseProps<'div'> {
  /**
   * assistiveText is optional.
   * Default value is "Προσοχή".
   * assistiveText is used to provide a textual warning for assistive technologies like screen readers.
   */
  assistiveText?: string;
  /**
   * dense is optional.
   * @value true WarningText will be dense.
   * @value false
   * @default false
   * */
  dense?: boolean;
}
/**
 * WarningText.
 * Use the WarningText component when you need to warn users about something important.
 * The component is used with a text inside it.
 */
export const WarningText = React.forwardRef<HTMLDivElement, WarningTextProps>(
  function WarningText(
    { className, assistiveText = 'Προσοχή', dense, children, ...props },
    ref
  ) {
    return (
      <Base
        as="div"
        ref={ref}
        className={clsx(className, {
          'ds-warning-text': true,
          'ds-warning-text--dense': dense,
        })}
        {...props}
      >
        <Base
          as="div"
          className={clsx({
            'ds-warning-text__icon': true,
          })}
        >
          !
        </Base>

        <Base
          as="strong"
          className={clsx({
            'ds-warning-text__content': true,
          })}
        >
          <WarningTextAssistive>{assistiveText}</WarningTextAssistive>
          {children}
        </Base>
      </Base>
    );
  }
);

export default WarningText;
