import React from 'react';
import clsx from 'clsx';
import Base, { BaseProps } from '@digigov/react-core/Base';

export interface WarningTextAssistiveProps extends BaseProps<'span'> {
  /**
   * assistiveText is optional.
   * Default value is "Προσοχή".
   * assistiveText is used to provide a textual warning for assistive technologies like screen readers.
   */
  assistiveText?: string;
}
/**
 * Use the WarningTextAssistive component when you need to warn users about something important.
 */
export const WarningTextAssistive = React.forwardRef<
  HTMLSpanElement,
  WarningTextAssistiveProps
>(function WarningTextAssistive(
  { className, children = 'Προσοχή', ...props },
  ref
) {
  return (
    <Base
      as="span"
      {...props}
      ref={ref}
      className={clsx(className, {
        'ds-warning-text__assistive': true,
      })}
    >
      {children}
    </Base>
  );
});

export default WarningTextAssistive;
